@@ -1,56 +1,62 @@
-
 #include "zm_ffmpeg_input.h"
-#include "zm_logger.h"
+
 #include "zm_ffmpeg.h"
+#include "zm_logger.h"
 
 FFmpeg_Input::FFmpeg_Input() {
-  input_format_context = NULL;
+  input_format_context = nullptr;
   video_stream_id = -1;
   audio_stream_id = -1;
   FFMPEGInit();
-  streams = NULL;
-  frame = NULL;
+  streams = nullptr;
+  frame = nullptr;
 	last_seek_request = -1;
 }
 
 FFmpeg_Input::~FFmpeg_Input() {
-  if ( streams ) {
-    for ( unsigned int i = 0; i < input_format_context->nb_streams; i += 1 ) {
-      avcodec_close(streams[i].context);
-      streams[i].context = NULL;
-    }
-    delete[] streams;
-    streams = NULL;
+  if ( input_format_context ) {
+    Close();
   }
   if ( frame ) {
     av_frame_free(&frame);
-    frame = NULL;
-  }
-  if ( input_format_context ) {
-#if !LIBAVFORMAT_VERSION_CHECK(53, 17, 0, 25, 0)
-    av_close_input_file(input_format_context);
-#else
-    avformat_close_input(&input_format_context);
-#endif
-    input_format_context = NULL;
+    frame = nullptr;
   }
 }  // end ~FFmpeg_Input()
 
+/* Takes streams provided from elsewhere.  They might not come from the same source
+ * but we will treat them as if they are.  */
+int FFmpeg_Input::Open(
+    const AVStream * video_in_stream,
+    const AVCodecContext * video_in_ctx,
+    const AVStream * audio_in_stream,
+    const AVCodecContext * audio_in_ctx
+    ) {
+  video_stream_id = video_in_stream->index;
+  int max_stream_index = video_in_stream->index;
+
+  if ( audio_in_stream ) {
+    max_stream_index = video_in_stream->index > audio_in_stream->index ? video_in_stream->index : audio_in_stream->index;
+    audio_stream_id = audio_in_stream->index;
+  }
+  streams = new stream[max_stream_index+1];
+  return 1;
+}
+
 int FFmpeg_Input::Open(const char *filepath) {
 
   int error;
 
   /** Open the input file to read from it. */
-  error = avformat_open_input(&input_format_context, filepath, NULL, NULL);
+  error = avformat_open_input(&input_format_context, filepath, nullptr, nullptr);
   if ( error < 0 ) {
-    Error("Could not open input file '%s' (error '%s')\n",
-        filepath, av_make_error_string(error).c_str() );
-    input_format_context = NULL;
+    Error("Could not open input file '%s' (error '%s')",
+        filepath, av_make_error_string(error).c_str());
+    input_format_context = nullptr;
     return error;
   }
 
   /** Get information on the input file (number of streams etc.). */
-  if ( (error = avformat_find_stream_info(input_format_context, NULL)) < 0 ) {
+  if ( (error = avformat_find_stream_info(input_format_context, nullptr)) < 0 ) {
     Error(
         "Could not open find stream info (error '%s')",
         av_make_error_string(error).c_str()
@@ -84,7 +90,7 @@ int FFmpeg_Input::Open(const char *filepath) {
 
     streams[i].frame_count = 0;
 #if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
-    streams[i].context = avcodec_alloc_context3(NULL);
+    streams[i].context = avcodec_alloc_context3(nullptr);
     avcodec_parameters_to_context(streams[i].context, input_format_context->streams[i]->codecpar);
 #else
     streams[i].context = input_format_context->streams[i]->codec;
@@ -98,7 +104,7 @@ int FFmpeg_Input::Open(const char *filepath) {
       Debug(1, "Using codec (%s) for stream %d", streams[i].codec->name, i);
     }
 
-    error = avcodec_open2(streams[i].context, streams[i].codec, NULL);
+    error = avcodec_open2(streams[i].context, streams[i].codec, nullptr);
     if ( error < 0 ) {
       Error("Could not open input codec (error '%s')",
           av_make_error_string(error).c_str());
@@ -106,19 +112,43 @@ int FFmpeg_Input::Open(const char *filepath) {
       avcodec_free_context(&streams[i].context);
 #endif
       avformat_close_input(&input_format_context);
-      input_format_context = NULL;
+      input_format_context = nullptr;
       return error;
     }
   } // end foreach stream
 
   if ( video_stream_id == -1 )
-    Error("Unable to locate video stream in %s", filepath);
+    Debug(1, "Unable to locate video stream in %s", filepath);
   if ( audio_stream_id == -1 )
     Debug(3, "Unable to locate audio stream in %s", filepath);
 
-  return 0;
+  return 1;
 } // end int FFmpeg_Input::Open( const char * filepath )
 
+int FFmpeg_Input::Close( ) {
+  if ( streams ) {
+    for ( unsigned int i = 0; i < input_format_context->nb_streams; i += 1 ) {
+      avcodec_close(streams[i].context);
+#if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
+      avcodec_free_context(&streams[i].context);
+      streams[i].context = nullptr;
+#endif
+    }
+    delete[] streams;
+    streams = nullptr;
+  }
+
+  if ( input_format_context ) {
+#if !LIBAVFORMAT_VERSION_CHECK(53, 17, 0, 25, 0)
+    av_close_input_file(input_format_context);
+#else
+    avformat_close_input(&input_format_context);
+#endif
+    input_format_context = nullptr;
+  }
+  return 1;
+} // end int FFmpeg_Input::Close()
+
 AVFrame *FFmpeg_Input::get_frame(int stream_id) {
   int frameComplete = false;
   AVPacket packet;
@@ -134,49 +164,49 @@ AVFrame *FFmpeg_Input::get_frame(int stream_id) {
           (ret == -110)
          ) {
         Info("av_read_frame returned %s.", av_make_error_string(ret).c_str());
-        return NULL;
+        return nullptr;
       }
       Error("Unable to read packet from stream %d: error %d \"%s\".",
           packet.stream_index, ret, av_make_error_string(ret).c_str());
-      return NULL;
+      return nullptr;
     }
-    dumpPacket(input_format_context->streams[packet.stream_index], &packet, "Received packet");
+    ZM_DUMP_STREAM_PACKET(input_format_context->streams[packet.stream_index], packet, "Received packet");
 
-    if ( (stream_id < 0) || (packet.stream_index == stream_id) ) {
-      Debug(3, "Packet is for our stream (%d)", packet.stream_index);
+    if ( (stream_id >= 0) && (packet.stream_index != stream_id) ) {
+      Debug(1,"Packet is not for our stream (%d)", packet.stream_index );
+      continue;
+    }
 
-      AVCodecContext *context = streams[packet.stream_index].context;
+    AVCodecContext *context = streams[packet.stream_index].context;
 
-      if ( frame ) {
-        av_frame_free(&frame);
-        frame = zm_av_frame_alloc();
+    if ( frame ) {
+      av_frame_free(&frame);
+      frame = zm_av_frame_alloc();
+    } else {
+      frame = zm_av_frame_alloc();
+    }
+    ret = zm_send_packet_receive_frame(context, frame, packet);
+    if ( ret < 0 ) {
+      Error("Unable to decode frame at frame %d: %d %s, continuing",
+          streams[packet.stream_index].frame_count, ret, av_make_error_string(ret).c_str());
+      zm_av_packet_unref(&packet);
+      av_frame_free(&frame);
+      continue;
+    } else {
+      if ( is_video_stream(input_format_context->streams[packet.stream_index]) ) {
+        zm_dump_video_frame(frame, "resulting video frame");
       } else {
-        frame = zm_av_frame_alloc();
-      }
-      ret = zm_send_packet_receive_frame(context, frame, packet);
-      if ( ret < 0 ) {
-        Error("Unable to decode frame at frame %d: %d %s, continuing",
-            streams[packet.stream_index].frame_count, ret, av_make_error_string(ret).c_str());
-        zm_av_packet_unref(&packet);
-        av_frame_free(&frame);
-        continue;
-			} else {
-        if ( is_video_stream(input_format_context->streams[packet.stream_index]) ) {
-          zm_dump_video_frame(frame, "resulting video frame");
-        } else {
-          zm_dump_frame(frame, "resulting frame");
-        }
+        zm_dump_frame(frame, "resulting frame");
       }
+    }
 
-      frameComplete = 1;
-    } // end if it's the right stream
+    frameComplete = 1;
 
     zm_av_packet_unref(&packet);
 
-  } // end while ! frameComplete
+  } // end while !frameComplete
   return frame;
-
-} //  end AVFrame *FFmpeg_Input::get_frame
+}  // end AVFrame *FFmpeg_Input::get_frame
 
 AVFrame *FFmpeg_Input::get_frame(int stream_id, double at) {
   Debug(1, "Getting frame from stream %d at %f", stream_id, at);
@@ -188,47 +218,58 @@ AVFrame *FFmpeg_Input::get_frame(int stream_id, double at) {
 
   int ret;
 
-  if ( !frame ) {
+  if (!frame) {
     // Don't have a frame yet, so get a keyframe before the timestamp
     ret = av_seek_frame(input_format_context, stream_id, seek_target, AVSEEK_FLAG_FRAME);
-    if ( ret < 0 ) {
+    if (ret < 0) {
       Error("Unable to seek in stream");
-      return NULL;
+      return nullptr;
     }
     // Have to grab a frame to update our current frame to know where we are
     get_frame(stream_id);
-  }  // end if ! frame
 
-	if ( !frame ) {
-		Warning("Unable to get frame.");
-		return NULL;
-	}
+    if (!frame) {
+      Warning("Unable to get frame.");
+      return nullptr;
+    }
+  }  // end if ! frame
 
   if ( 
 			(last_seek_request >= 0)
 			&&
-			(last_seek_request > seek_target ) 
+			(last_seek_request > seek_target) 
 			&&
 			(frame->pts > seek_target)
 		 ) {
     zm_dump_frame(frame, "frame->pts > seek_target, seek backwards");
   // our frame must be beyond our seek target. so go backwards to before it
-    if ( ( ret = av_seek_frame(input_format_context, stream_id, seek_target, 
+    if (( ret = av_seek_frame(input_format_context, stream_id, seek_target, 
             AVSEEK_FLAG_BACKWARD | AVSEEK_FLAG_FRAME
-            ) < 0 ) ) {
-      Error("Unable to seek in stream");
-      return NULL;
+            ) ) < 0) {
+      Error("Unable to seek in stream %d", ret);
+      return nullptr;
     }
     // Have to grab a frame to update our current frame to know where we are
     get_frame(stream_id);
-    zm_dump_frame(frame, "frame->pts > seek_target, got");
+    if ( is_video_stream(input_format_context->streams[stream_id]) ) {
+      zm_dump_video_frame(frame, "frame->pts > seek_target, got");
+    } else {
+      zm_dump_frame(frame, "frame->pts > seek_target, got");
+    }
+  } else if ( last_seek_request == seek_target ) {
+    // paused case, sending keepalives
+    return frame;
   } // end if frame->pts > seek_target
 
 	last_seek_request = seek_target;
 
   // Seeking seems to typically seek to a keyframe, so then we have to decode until we get the frame we want.
   if ( frame->pts <= seek_target ) {
-    zm_dump_frame(frame, "pts <= seek_target");
+    if ( is_video_stream(input_format_context->streams[stream_id]) ) {
+      zm_dump_video_frame(frame, "pts <= seek_target");
+    } else {
+      zm_dump_frame(frame, "pts <= seek_target");
+    }
     while ( frame && (frame->pts < seek_target) ) {
       if ( !get_frame(stream_id) ) {
         Warning("Got no frame. returning nothing");
