@@ -19,42 +19,28 @@
 
 #include "zm_logger.h"
 
-#include "zm_config.h"
-#include "zm_utils.h"
 #include "zm_db.h"
-
-#include <unistd.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <sys/time.h>
-#include <syslog.h>
-#include <signal.h>
-#include <stdarg.h>
-#include <errno.h>
+#include "zm_utils.h"
 #include <libgen.h>
+#include <syslog.h>
+#include <sys/time.h>
+#include <unistd.h>
+
 #ifdef __FreeBSD__
 #include <sys/thr.h>
 #endif
+#include <cerrno>
+#include <csignal>
+#include <cstdarg>
+#include <cstring>
+
 
 bool Logger::smInitialised = false;
-Logger *Logger::smInstance = NULL;
+Logger *Logger::smInstance = nullptr;
 
 Logger::StringMap Logger::smCodes;
 Logger::IntMap Logger::smSyslogPriorities;
 
-#if 0
-static void subtractTime( struct timeval * const tp1, struct timeval * const tp2 ) {
-  tp1->tv_sec -= tp2->tv_sec;
-  if ( tp1->tv_usec <= tp2->tv_usec ) {
-    tp1->tv_sec--;
-    tp1->tv_usec = 1000000 - (tp2->tv_usec - tp1->tv_usec);
-  } else {
-    tp1->tv_usec = tp1->tv_usec - tp2->tv_usec;
-  }
-}
-#endif
-
 void Logger::usrHandler(int sig) {
   Logger *logger = fetch();
   if ( sig == SIGUSR1 )
@@ -73,16 +59,15 @@ Logger::Logger() :
   mEffectiveLevel(NOLOG),
   mDbConnected(false),
   mLogPath(staticConfig.PATH_LOGS.c_str()),
-  //mLogFile( mLogPath+"/"+mId+".log" ),
-  mLogFileFP(NULL),
+  //  mLogFile( mLogPath+"/"+mId+".log" ),
+  mLogFileFP(nullptr),
   mHasTerminal(false),
   mFlush(false) {
-
-  if ( smInstance ) {
+  if (smInstance) {
     Panic("Attempt to create second instance of Logger class");
   }
 
-  if ( !smInitialised ) {
+  if (!smInitialised) {
     smCodes[INFO] = "INF";
     smCodes[WARNING] = "WAR";
     smCodes[ERROR] = "ERR";
@@ -97,16 +82,16 @@ Logger::Logger() :
     smSyslogPriorities[PANIC] = LOG_ERR;
 
     char code[4] = "";
-    for ( int i = DEBUG1; i <= DEBUG9; i++ ) {
+    for (int i = DEBUG1; i <= DEBUG9; i++) {
       snprintf(code, sizeof(code), "DB%d", i);
       smCodes[i] = code;
       smSyslogPriorities[i] = LOG_DEBUG;
     }
 
     smInitialised = true;
-  }
+  }  // end if ! smInitialised
 
-  if ( fileno(stderr) && isatty(fileno(stderr)) ) {
+  if (fileno(stderr) && isatty(fileno(stderr))) {
     mHasTerminal = true;
     mTerminalLevel = WARNING;
   }
@@ -117,14 +102,6 @@ Logger::~Logger() {
   smCodes.clear();
   smSyslogPriorities.clear();
   smInitialised = false;
-#if 0
-  for ( StringMap::iterator itr = smCodes.begin(); itr != smCodes.end(); itr ++ ) {
-      smCodes.erase( itr );
-  }
-  for ( IntMap::iterator itr = smSyslogPriorities.begin(); itr != smSyslogPriorities.end(); itr ++ ) {
-      smSyslogPriorities.erase(itr);
-  }
-#endif
 }
 
 void Logger::initialise(const std::string &id, const Options &options) {
@@ -149,24 +126,24 @@ void Logger::initialise(const std::string &id, const Options &options) {
 
   Level tempLevel = INFO;
   Level tempTerminalLevel = mTerminalLevel;
-  Level tempDatabaseLevel = mDatabaseLevel;
-  Level tempFileLevel = mFileLevel;
-  Level tempSyslogLevel = mSyslogLevel;
 
   if ( options.mTerminalLevel != NOOPT )
     tempTerminalLevel = options.mTerminalLevel;
 
-  // DEBUG1 == 1.  So >= DEBUG1, we set to DEBUG9?! Why?
+  // DEBUG1 == 1.  So >= DEBUG1, we set to DEBUG9?! Why? icon: because log_level_database only goes up to debug.
+  Level tempDatabaseLevel;
   if ( options.mDatabaseLevel != NOOPT )
     tempDatabaseLevel = options.mDatabaseLevel;
   else
     tempDatabaseLevel = config.log_level_database >= DEBUG1 ? DEBUG9 : config.log_level_database;
 
+  Level tempFileLevel;
   if ( options.mFileLevel != NOOPT )
     tempFileLevel = options.mFileLevel;
   else
     tempFileLevel = config.log_level_file >= DEBUG1 ? DEBUG9 : config.log_level_file;
 
+  Level tempSyslogLevel;
   if ( options.mSyslogLevel != NOOPT )
     tempSyslogLevel = options.mSyslogLevel;
   else
@@ -189,7 +166,7 @@ void Logger::initialise(const std::string &id, const Options &options) {
     tempSyslogLevel = atoi(envPtr);
 
   if ( config.log_debug ) {
-    StringVector targets = split(config.log_debug_target, "|");
+    StringVector targets = Split(config.log_debug_target, "|");
     for ( unsigned int i = 0; i < targets.size(); i++ ) {
       const std::string &target = targets[i];
       if ( target == mId || target == "_"+mId || target == "_"+mIdRoot || target == "" ) {
@@ -201,7 +178,7 @@ void Logger::initialise(const std::string &id, const Options &options) {
           }
         }
       }
-    } // end foreach target
+    }  // end foreach target
   } else {
     // if we don't have debug turned on, then the max effective log level is INFO
     if ( tempSyslogLevel > INFO ) tempSyslogLevel = INFO;
@@ -209,7 +186,7 @@ void Logger::initialise(const std::string &id, const Options &options) {
     if ( tempTerminalLevel > INFO ) tempTerminalLevel = INFO;
     if ( tempDatabaseLevel > INFO ) tempDatabaseLevel = INFO;
     if ( tempLevel > INFO ) tempLevel = INFO;
-  } // end if config.log_debug
+  }  // end if config.log_debug
 
   logFile(tempLogFile);
 
@@ -283,9 +260,7 @@ std::string Logger::strEnv(const std::string &name, const std::string &defaultVa
 }
 
 char *Logger::getTargettedEnv(const std::string &name) {
-  std::string envName;
-
-  envName = name+"_"+mId;
+  std::string envName = name+"_"+mId;
   char *envPtr = getenv(envName.c_str());
   if ( !envPtr && mId != mIdRoot ) {
     envName = name+"_"+mIdRoot;
@@ -322,9 +297,7 @@ const std::string &Logger::id(const std::string &id) {
 
 Logger::Level Logger::level(Logger::Level level) {
   if ( level > NOOPT ) {
-    level = limit(level);
-    if ( mLevel != level )
-      mLevel = level;
+    mLevel = limit(level);
 
     mEffectiveLevel = NOLOG;
     if ( mTerminalLevel > mEffectiveLevel )
@@ -349,35 +322,33 @@ Logger::Level Logger::terminalLevel(Logger::Level terminalLevel) {
   if ( terminalLevel > NOOPT ) {
     if ( !mHasTerminal )
       terminalLevel = NOLOG;
-    terminalLevel = limit(terminalLevel);
-    if ( mTerminalLevel != terminalLevel )
-      mTerminalLevel = terminalLevel;
+    mTerminalLevel = limit(terminalLevel);
   }
   return mTerminalLevel;
 }
 
 Logger::Level Logger::databaseLevel(Logger::Level databaseLevel) {
-  if ( databaseLevel > NOOPT ) {
+  if (databaseLevel > NOOPT) {
     databaseLevel = limit(databaseLevel);
-    if ( mDatabaseLevel != databaseLevel ) {
-      if ( (databaseLevel > NOLOG) && (mDatabaseLevel <= NOLOG) ) { // <= NOLOG would be NOOPT
-        if ( !zmDbConnect() ) {
+    if (mDatabaseLevel != databaseLevel) {
+      if ((databaseLevel > NOLOG) && (mDatabaseLevel <= NOLOG)) { // <= NOLOG would be NOOPT
+        if (!zmDbConnected) {
           databaseLevel = NOLOG;
         }
-      }  // end if ( databaseLevel > NOLOG && mDatabaseLevel <= NOLOG )
+      }
       mDatabaseLevel = databaseLevel;
-    }  // end if ( mDatabaseLevel != databaseLevel )
-  }  // end if ( databaseLevel > NOOPT )
+    }
+  }
 
   return mDatabaseLevel;
 }
 
 Logger::Level Logger::fileLevel(Logger::Level fileLevel) {
-  if ( fileLevel > NOOPT ) {
+  if (fileLevel > NOOPT) {
     fileLevel = limit(fileLevel);
     // Always close, because we may have changed file names
-    if ( mFileLevel > NOLOG )
-	    closeFile();
+    if (mFileLevel > NOLOG)
+      closeFile();
     mFileLevel = fileLevel;
     // Don't try to open it here because it will create the log file even if we never write to it.
   }
@@ -385,13 +356,13 @@ Logger::Level Logger::fileLevel(Logger::Level fileLevel) {
 }
 
 Logger::Level Logger::syslogLevel(Logger::Level syslogLevel) {
-  if ( syslogLevel > NOOPT ) {
+  if (syslogLevel > NOOPT) {
     syslogLevel = limit(syslogLevel);
-    if ( mSyslogLevel != syslogLevel ) {
-      if ( mSyslogLevel > NOLOG )
+    if (mSyslogLevel != syslogLevel) {
+      if (mSyslogLevel > NOLOG)
         closeSyslog();
       mSyslogLevel = syslogLevel;
-      if ( mSyslogLevel > NOLOG )
+      if (mSyslogLevel > NOLOG)
         openSyslog();
     }
   }
@@ -401,40 +372,39 @@ Logger::Level Logger::syslogLevel(Logger::Level syslogLevel) {
 void Logger::logFile(const std::string &logFile) {
   bool addLogPid = false;
   std::string tempLogFile = logFile;
-  if ( tempLogFile[tempLogFile.length()-1] == '+' ) {
+  if (tempLogFile[tempLogFile.length()-1] == '+') {
     tempLogFile.resize(tempLogFile.length()-1);
     addLogPid = true;
   }
-  if ( addLogPid )
+  if (addLogPid)
     mLogFile = stringtf("%s.%05d", tempLogFile.c_str(), getpid());
   else
     mLogFile = tempLogFile;
 }
 
 void Logger::openFile() {
-  if ( mLogFile.size() ) {
-   if ( (mLogFileFP = fopen(mLogFile.c_str(), "a")) == (FILE *)NULL ) {
-    mFileLevel = NOLOG;
-    Error("fopen() for %s, error = %s", mLogFile.c_str(), strerror(errno));
-   }
+  if (mLogFile.size()) {
+    if ( (mLogFileFP = fopen(mLogFile.c_str(), "a")) == nullptr ) {
+      mFileLevel = NOLOG;
+      Error("fopen() for %s, error = %s", mLogFile.c_str(), strerror(errno));
+    }
   } else {
     puts("Called Logger::openFile() without a filename");
   }
 }
 
 void Logger::closeFile() {
-  if ( mLogFileFP ) {
+  if (mLogFileFP) {
     fflush(mLogFileFP);
-    if ( fclose(mLogFileFP) < 0 ) {
-      mLogFileFP = (FILE *)NULL;
+    if (fclose(mLogFileFP) < 0) {
+      mLogFileFP = nullptr;
       Error("fclose(), error = %s", strerror(errno));
     }
-    mLogFileFP = (FILE *)NULL;
+    mLogFileFP = nullptr;
   }
 }
 
 void Logger::closeDatabase() {
-
 }
 
 void Logger::openSyslog() {
@@ -445,26 +415,23 @@ void Logger::closeSyslog() {
   (void) closelog();
 }
 
-void Logger::logPrint(bool hex, const char * const filepath, const int line, const int level, const char *fstring, ...) {
-  
-  if ( level > mEffectiveLevel ) {
-    return;
-  }
+void Logger::logPrint(bool hex, const char *filepath, int line, int level, const char *fstring, ...) {
+  if (level > mEffectiveLevel) return;
+  if (level < PANIC || level > DEBUG9)
+    Panic("Invalid logger level %d", level);
     
   log_mutex.lock();
+  // Can we save some cycles by having these as members and not allocate them on the fly? I think so.
   char            timeString[64];
-  char            logString[8192];
+  char            logString[4096]; // SQL TEXT can hold 64k so we could go up to 32k here but why?
   va_list         argPtr;
   struct timeval  timeVal;
 
-  char *filecopy = strdup(filepath);
-  const char * const file = basename(filecopy);
+  const char *base = strrchr(filepath, '/');
+  const char *file = base ? base+1 : filepath;
   const char *classString = smCodes[level].c_str();
 
-  if ( level < PANIC || level > DEBUG9 )
-    Panic("Invalid logger level %d", level);
-
-  gettimeofday(&timeVal, NULL);
+  gettimeofday(&timeVal, nullptr);
 
 #if 0
   if ( logRuntime ) {
@@ -476,7 +443,8 @@ void Logger::logPrint(bool hex, const char * const filepath, const int line, con
   } else {
 #endif
     char *timePtr = timeString;
-    timePtr += strftime(timePtr, sizeof(timeString), "%x %H:%M:%S", localtime(&timeVal.tv_sec));
+    tm now_tm = {};
+    timePtr += strftime(timePtr, sizeof(timeString), "%x %H:%M:%S", localtime_r(&timeVal.tv_sec, &now_tm));
     snprintf(timePtr, sizeof(timeString)-(timePtr-timeString), ".%06ld", timeVal.tv_usec);
 #if 0
   }
@@ -492,12 +460,12 @@ void Logger::logPrint(bool hex, const char * const filepath, const int line, con
 #else
   #ifdef HAVE_SYSCALL
     #ifdef __FreeBSD_kernel__
-    if ( (syscall(SYS_thr_self, &tid)) < 0 ) // Thread/Process id
+    if ((syscall(SYS_thr_self, &tid)) < 0)  // Thread/Process id
 
     # else
       // SOLARIS doesn't have SYS_gettid; don't assume
       #ifdef SYS_gettid
-    if ( (tid = syscall(SYS_gettid)) < 0 ) // Thread/Process id
+    if ((tid = syscall(SYS_gettid)) < 0)  // Thread/Process id
       #endif // SYS_gettid
     #endif
   #endif // HAVE_SYSCALL
@@ -529,82 +497,74 @@ void Logger::logPrint(bool hex, const char * const filepath, const int line, con
   }
   va_end(argPtr);
   char *syslogEnd = logPtr;
+
+  if ( static_cast<size_t>(logPtr - logString) >= sizeof(logString) ) {
+    // vsnprintf won't exceed the the buffer, but it might hit the end.
+    logPtr = logString + sizeof(logString)-3;
+  }
   strncpy(logPtr, "]\n", sizeof(logString)-(logPtr-logString));
 
-  if ( level <= mTerminalLevel ) {
+  if (level <= mTerminalLevel) {
     puts(logString);
     fflush(stdout);
   }
-  if ( level <= mFileLevel ) {
-    if ( !mLogFileFP ) {
-      log_mutex.unlock();
+
+  if (level <= mFileLevel) {
+    if (!mLogFileFP) {
+      // FIXME unlocking here is a problem. Another thread could sneak in.
+      // We are using a recursive mutex so unlocking shouldn't be neccessary
+      //log_mutex.unlock();
+      // We do this here so that we only create the file if we ever write to it.
       openFile();
-      log_mutex.lock();
+      //log_mutex.lock();
     }
-    if ( mLogFileFP ) {
+    if (mLogFileFP) {
       fputs(logString, mLogFileFP);
-      if ( mFlush )
-        fflush(mLogFileFP);
-    } else {
-      puts("Logging to file, but failed to open it\n");
+      if (mFlush) fflush(mLogFileFP);
+    } else if (mTerminalLevel != NOLOG) {
+      puts("Logging to file but failed to open it\n");
     }
-#if 0
-  } else {
-    printf("Not writing to log file because level %d %s <= mFileLevel %d %s\nstring: %s\n",
-        level, smCodes[level].c_str(), mFileLevel, smCodes[mFileLevel].c_str(), logString);
-#endif
-  }
-  *syslogEnd = '\0';
-  if ( level <= mDatabaseLevel ) {
-    char sql[ZM_SQL_MED_BUFSIZ];
-    char escapedString[(strlen(syslogStart)*2)+1];
+  }  // end if level <= mFileLevel
 
-    if ( !db_mutex.trylock() ) {
-      mysql_real_escape_string(&dbconn, escapedString, syslogStart, strlen(syslogStart));
+  if (level <= mDatabaseLevel) {
+    if (zmDbConnected) {
+      int syslogSize = syslogEnd - syslogStart;
+      std::string escapedString;
+      escapedString.resize((syslogSize * 2) + 1);
+      mysql_real_escape_string(&dbconn, &escapedString[0], syslogStart, syslogSize);
+      escapedString.resize(std::strlen(escapedString.c_str()));
 
-      snprintf(sql, sizeof(sql),
+      std::string sql_string = stringtf(
           "INSERT INTO `Logs` "
           "( `TimeKey`, `Component`, `ServerId`, `Pid`, `Level`, `Code`, `Message`, `File`, `Line` )"
-         " VALUES "
-         "( %ld.%06ld, '%s', %d, %d, %d, '%s', '%s', '%s', %d )",
-         timeVal.tv_sec, timeVal.tv_usec, mId.c_str(), staticConfig.SERVER_ID, tid, level, classString, escapedString, file, line
-         );
-      if ( mysql_query(&dbconn, sql) ) {
-        Level tempDatabaseLevel = mDatabaseLevel;
-        databaseLevel(NOLOG);
-        Error("Can't insert log entry: sql(%s) error(%s)", sql, mysql_error(&dbconn));
-        databaseLevel(tempDatabaseLevel);
-      }
-      db_mutex.unlock();
+          " VALUES "
+          "( %ld.%06ld, '%s', %d, %d, %d, '%s', '%s', '%s', %d )",
+          timeVal.tv_sec, timeVal.tv_usec, mId.c_str(), staticConfig.SERVER_ID, tid, level, classString, escapedString.c_str(), file, line
+          );
+      dbQueue.push(std::move(sql_string));
     } else {
-      Level tempDatabaseLevel = mDatabaseLevel;
-      databaseLevel(NOLOG);
-      Error("Can't insert log entry: sql(%s) error(db is locked)", logString);
-      databaseLevel(tempDatabaseLevel);
+      puts("Db is closed");
     }
-  }
-  if ( level <= mSyslogLevel ) {
-    int priority = smSyslogPriorities[level];
-    //priority |= LOG_DAEMON;
-    syslog(priority, "%s [%s] [%s]", classString, mId.c_str(), syslogStart);
+  }  // end if level <= mDatabaseLevel
+
+  if (level <= mSyslogLevel) {
+    *syslogEnd = '\0';
+    syslog(smSyslogPriorities[level], "%s [%s] [%s]", classString, mId.c_str(), syslogStart);
   }
 
-  free(filecopy);
-  if ( level <= FATAL ) {
-    log_mutex.unlock();
+  log_mutex.unlock();
+  if (level <= FATAL) {
     logTerm();
     zmDbClose();
-    if ( level <= PANIC )
-      abort();
+    if (level <= PANIC) abort();
     exit(-1);
   }
-  log_mutex.unlock();
 }  // end logPrint
 
 void logInit(const char *name, const Logger::Options &options) {
-  if ( Logger::smInstance ) {
+  if (Logger::smInstance) {
     delete Logger::smInstance;
-    Logger::smInstance = NULL;
+    Logger::smInstance = nullptr;
   }
 
   Logger::smInstance = new Logger();
@@ -612,8 +572,8 @@ void logInit(const char *name, const Logger::Options &options) {
 }
 
 void logTerm() {
-  if ( Logger::smInstance ) {
+  if (Logger::smInstance) {
     delete Logger::smInstance;
-    Logger::smInstance = NULL;
+    Logger::smInstance = nullptr;
   }
 }
