@@ -229,6 +229,7 @@ void MonitorStream::processCommand(const CmdMsg *msg) {
       break;
     case CMD_QUIT :
       Info("User initiated exit - CMD_QUIT");
+      zm_terminate = true;
       break;
     case CMD_QUERY :
       Debug(1, "Got QUERY command, sending STATUS");
@@ -315,16 +316,6 @@ void MonitorStream::processCommand(const CmdMsg *msg) {
     }
   }
   Debug(2, "Number of bytes sent to (%s): (%d)", rem_addr.sun_path, nbytes);
-
-  // quit after sending a status, if this was a quit request
-  if ( (MsgCommand)msg->msg_data[0] == CMD_QUIT ) {
-    zm_terminate = true;
-    Debug(2, "Quitting");
-    return;
-  }
-
-  //Debug(2,"Updating framerate");
-  //updateFrameRate(monitor->GetFPS());
 }  // end void MonitorStream::processCommand(const CmdMsg *msg)
 
 bool MonitorStream::sendFrame(const char *filepath, const timeval &timestamp) {
@@ -387,9 +378,10 @@ bool MonitorStream::sendFrame(const char *filepath, const timeval &timestamp) {
 } // end bool MonitorStream::sendFrame(const char *filepath, struct timeval *timestamp)
 
 bool MonitorStream::sendFrame(Image *image, const timeval &timestamp) {
+  if (!config.timestamp_on_capture) {
+    monitor->TimestampImage(image, timestamp);
+  }
   Image *send_image = prepareImage(image);
-  if (!config.timestamp_on_capture)
-    monitor->TimestampImage(send_image, timestamp);
 
   fputs("--" BOUNDARY "\r\n", stdout);
 #if HAVE_LIBAVCODEC
@@ -873,14 +865,16 @@ void MonitorStream::SingleImage(int scale) {
   Debug(1, "write index: %d %d", monitor->shared_data->last_write_index, index);
   Image *snap_image = monitor->image_buffer[index];
 
+  if (!config.timestamp_on_capture) {
+    monitor->TimestampImage(snap_image, monitor->shared_timestamps[index]);
+  }
+
   if ( scale != ZM_SCALE_BASE ) {
     scaled_image.Assign(*snap_image);
     scaled_image.Scale(scale);
     snap_image = &scaled_image;
   }
-  if ( !config.timestamp_on_capture ) {
-    monitor->TimestampImage(snap_image, monitor->shared_timestamps[index]);
-  }
+
   snap_image->EncodeJpeg(img_buffer, &img_buffer_size);
 
   fprintf(stdout,
