@@ -11,7 +11,7 @@ int zm_sendfile(int out_fd, int in_fd, off_t *offset, size_t size) {
   int err;
 
   err = sendfile(out_fd, in_fd, offset, size);
-  if (err < 0)
+  if ( err < 0 )
     return -errno;
 
   return err;
@@ -22,7 +22,7 @@ int zm_sendfile(int out_fd, int in_fd, off_t *offset, size_t size) {
 #include <sys/uio.h>
 int zm_sendfile(int out_fd, int in_fd, off_t *offset, off_t size) {
   int err;
-  err = sendfile(in_fd, out_fd, *offset, size, NULL, &size, 0);
+  err = sendfile(in_fd, out_fd, *offset, size, nullptr, &size, 0);
   if (err && errno != EAGAIN)
     return -errno;
 
