@@ -1,13 +1,20 @@
 <?php
 if ( $_REQUEST['entity'] == 'navBar' ) {
+  global $bandwidth_options, $user;
   $data = array();
   if ( ZM_OPT_USE_AUTH && (ZM_AUTH_RELAY == 'hashed') ) {
     $auth_hash = generateAuthHash(ZM_AUTH_HASH_IPS);
-    if ( isset($_REQUEST['auth']) and ($_REQUEST['auth'] != $auth_hash) ) {
-      $data['auth'] = $auth_hash;
-    }
+    $data['auth'] = $auth_hash;
+    $data['auth_relay'] = get_auth_relay();
   }
-  $data['message'] = getNavBarHtml('reload');
+  // Each widget on the navbar has its own function
+  // Call the functions we want to dynamically update
+  $data['getBandwidthHTML'] = getBandwidthHTML($bandwidth_options, $user);
+  $data['getSysLoadHTML'] = getSysLoadHTML();
+  $data['getDbConHTML'] = getDbConHTML();
+  $data['getStorageHTML'] = getStorageHTML();
+  $data['getShmHTML'] = getShmHTML();
+
   ajaxResponse($data);
   return;
 }
@@ -100,9 +107,11 @@ $statusData = array(
       'Name' => true,
       'Cause' => true,
       'Notes' => true,
-      'StartTime' => true,
-      'StartTimeShort' => array( 'sql' => 'date_format( StartTime, \''.MYSQL_FMT_DATETIME_SHORT.'\' )' ), 
-      'EndTime' => true,
+      'StartDateTime' => true,
+      # Left for backwards compatability. Remove in 1.37
+      'StartTimeShort' => array( 'sql' => 'date_format( StartDateTime, \''.MYSQL_FMT_DATETIME_SHORT.'\' )' ), 
+      'StartDateTimeShort' => array( 'sql' => 'date_format( StartDateTime, \''.MYSQL_FMT_DATETIME_SHORT.'\' )' ), 
+      'EndDateTime' => true,
       'Width' => true,
       'Height' => true,
       'Length' => true,
@@ -124,9 +133,13 @@ $statusData = array(
       'MonitorName' => array('sql' => '(SELECT Monitors.Name FROM Monitors WHERE Monitors.Id = Events.MonitorId)'),
       'Name' => true,
       'Cause' => true,
-      'StartTime' => true,
-      'StartTimeShort' => array( 'sql' => 'date_format( StartTime, \''.MYSQL_FMT_DATETIME_SHORT.'\' )' ), 
-      'EndTime' => true,
+      'DiskSpace' => true,
+      'Storage' => array('sql' => '(SELECT Storage.Name FROM Storage WHERE Storage.Id=Events.StorageId)'),
+      'StartDateTime' => true,
+      # Left for backwards compatability. Remove in 1.37
+      'StartTimeShort' => array( 'sql' => 'date_format( StartDateTime, \''.MYSQL_FMT_DATETIME_SHORT.'\' )' ), 
+      'StartDateTimeShort' => array( 'sql' => 'date_format( StartDateTime, \''.MYSQL_FMT_DATETIME_SHORT.'\' )' ), 
+      'EndDateTime' => true,
       'Width' => true,
       'Height' => true,
       'Length' => true,
@@ -171,7 +184,7 @@ $statusData = array(
       'EventId' => true,
       'Type' => true,
       'TimeStamp' => true,
-      'TimeStampShort' => array( 'sql' => 'date_format( StartTime, \''.MYSQL_FMT_DATETIME_SHORT.'\' )' ), 
+      'TimeStampShort' => array( 'sql' => 'date_format( StartDateTime, \''.MYSQL_FMT_DATETIME_SHORT.'\' )' ), 
       'Delta' => true,
       'Score' => true,
       //'Image' => array( 'postFunc' => 'getFrameImage' ),
@@ -263,9 +276,9 @@ function collectData() {
       if ( $id && !empty($entitySpec['selector']) ) {
         $index = 0;
         $where = array();
-        foreach( $entitySpec['selector'] as $selIndex => $selector ) {
+        foreach ( $entitySpec['selector'] as $selIndex => $selector ) {
           $selectorParamName = ':selector' . $selIndex;
-          if ( is_array( $selector ) ) {
+          if ( is_array($selector) ) {
             $where[] = $selector['selector'].' = '.$selectorParamName;
             $values[$selectorParamName] = validInt($id[$index]);
           } else {
@@ -280,15 +293,15 @@ function collectData() {
         $sql .= ' GROUP BY '.join(',', array_unique($groupSql));
       if ( !empty($_REQUEST['sort']) ) {
         $sql .= ' ORDER BY ';
-        $sort_fields = explode(',',$_REQUEST['sort']);
+        $sort_fields = explode(',', $_REQUEST['sort']);
         foreach ( $sort_fields as $sort_field ) {
           
-          preg_match('/^(\w+)\s*(ASC|DESC)?( NULLS FIRST)?$/i', $sort_field, $matches);
+          preg_match('/^`?(\w+)`?\s*(ASC|DESC)?( NULLS FIRST)?$/i', $sort_field, $matches);
           if ( count($matches) ) {
             if ( in_array($matches[1], $fieldSql) or  in_array('`'.$matches[1].'`', $fieldSql) ) {
               $sql .= $matches[1];
             } else {
-              ZM\Error('Sort field ' . $matches[1] . ' not in SQL Fields');
+              ZM\Error('Sort field '.$matches[1].' from ' .$sort_field.' not in SQL Fields: '.join(',', $sort_field));
             }
             if ( count($matches) > 2 ) {
               $sql .= ' '.strtoupper($matches[2]);
@@ -304,30 +317,30 @@ function collectData() {
         $limit = $entitySpec['limit'];
       elseif ( !empty($_REQUEST['count']) )
         $limit = validInt($_REQUEST['count']);
-      $limit_offset='';
+      $limit_offset = '';
       if ( !empty($_REQUEST['offset']) )
         $limit_offset = validInt($_REQUEST['offset']) . ', ';
-      if ( !empty( $limit ) )
+      if ( !empty($limit) )
         $sql .= ' limit '.$limit_offset.$limit;
       if ( isset($limit) && $limit == 1 ) {
         if ( $sqlData = dbFetchOne($sql, NULL, $values) ) {
           foreach ( $postFuncs as $element=>$func )
             $sqlData[$element] = eval( 'return( '.$func.'( $sqlData ) );' );
-          $data = array_merge( $data, $sqlData );
+          $data = array_merge($data, $sqlData);
         }
       } else {
         $count = 0;
-        foreach( dbFetchAll( $sql, NULL, $values ) as $sqlData ) {
+        foreach ( dbFetchAll($sql, NULL, $values) as $sqlData ) {
           foreach ( $postFuncs as $element=>$func )
-            $sqlData[$element] = eval( 'return( '.$func.'( $sqlData ) );' );
+            $sqlData[$element] = eval('return( '.$func.'( $sqlData ) );');
           $data[] = $sqlData;
-          if ( isset($limi) && ++$count >= $limit )
+          if ( isset($limit) && ++$count >= $limit )
             break;
-        }
-      }
+        } # end foreach
+      } # end if have limit == 1
     }
   }
-  #ZM\Logger::Debug(print_r($data, true));
+  #ZM\Debug(print_r($data, true));
   return $data;
 }
 
@@ -337,33 +350,34 @@ if ( !isset($_REQUEST['layout']) ) {
   $_REQUEST['layout'] = 'json';
 }
 
-switch( $_REQUEST['layout'] ) {
+switch ( $_REQUEST['layout'] ) {
   case 'xml NOT CURRENTLY SUPPORTED' :
-      header('Content-type: application/xml');
-      echo('<?xml version="1.0" encoding="iso-8859-1"?>
-');
-      echo '<'.strtolower($_REQUEST['entity']).'>
+    header('Content-type: application/xml');
+    echo('<?xml version="1.0" encoding="iso-8859-1"?>
+      ');
+    echo '<'.strtolower($_REQUEST['entity']).'>
 ';
-      foreach ( $data as $key=>$value ) {
-        $key = strtolower($key);
-        echo "<$key>".htmlentities($value)."</$key>\n";
-      }
-      echo '</'.strtolower($_REQUEST['entity']).">\n";
-      break;
+    foreach ( $data as $key=>$value ) {
+      $key = strtolower($key);
+      echo "<$key>".htmlentities($value)."</$key>\n";
+    }
+    echo '</'.strtolower($_REQUEST['entity']).">\n";
+    break;
   case 'json' :
     {
       $response = array( strtolower(validJsStr($_REQUEST['entity'])) => $data );
       if ( isset($_REQUEST['loopback']) )
         $response['loopback'] = validJsStr($_REQUEST['loopback']);
+        #ZM\Warning(print_r($response, true));
       ajaxResponse($response);
       break;
     }
   case 'text' :
-      header('Content-type: text/plain' );
-      echo join( ' ', array_values( $data ) );
-      break;
+    header('Content-type: text/plain');
+    echo join(' ', array_values($data));
+    break;
   default:
-    ZM\Error('Unsupported layout: '. $_REQUEST['layout']);
+    ZM\Error('Unsupported layout: '.$_REQUEST['layout']);
 }
 
 function getFrameImage() {
@@ -371,86 +385,96 @@ function getFrameImage() {
   $frameId = $_REQUEST['id'][1];
 
   $sql = 'SELECT * FROM Frames WHERE EventId = ? AND FrameId = ?';
-  if ( !($frame = dbFetchOne( $sql, NULL, array($eventId, $frameId ) )) ) {
+  if ( !($frame = dbFetchOne($sql, NULL, array($eventId, $frameId))) ) {
     $frame = array();
     $frame['EventId'] = $eventId;
     $frame['FrameId'] = $frameId;
     $frame['Type'] = 'Virtual';
   }
-  $event = dbFetchOne( 'select * from Events where Id = ?', NULL, array( $frame['EventId'] ) );
-  $frame['Image'] = getImageSrc( $event, $frame, SCALE_BASE );
-  return( $frame );
+  $event = dbFetchOne('SELECT * FROM Events WHERE Id = ?', NULL, array($frame['EventId']));
+  $frame['Image'] = getImageSrc($event, $frame, SCALE_BASE);
+  return $frame;
 }
 
 function getNearFrame() {
   $eventId = $_REQUEST['id'][0];
   $frameId = $_REQUEST['id'][1];
 
-  $sql = 'select FrameId from Frames where EventId = ? and FrameId <= ? order by FrameId desc limit 1';
-  if ( !$nearFrameId = dbFetchOne( $sql, 'FrameId', array( $eventId, $frameId ) ) ) {
-    $sql = 'select * from Frames where EventId = ? and FrameId > ? order by FrameId asc limit 1';
-    if ( !$nearFrameId = dbFetchOne( $sql, 'FrameId', array( $eventId, $frameId ) ) ) {
+  $sql = 'SELECT FrameId FROM Frames WHERE EventId = ? AND FrameId <= ? ORDER BY FrameId DESC LIMIT 1';
+  if ( !$nearFrameId = dbFetchOne($sql, 'FrameId', array($eventId, $frameId)) ) {
+    $sql = 'SELECT * FROM Frames WHERE EventId = ? AND FrameId > ? ORDER BY FrameId ASC LIMIT 1';
+    if ( !$nearFrameId = dbFetchOne($sql, 'FrameId', array($eventId, $frameId)) ) {
       return( array() );
     }
   }
   $_REQUEST['entity'] = 'frame';
   $_REQUEST['id'][1] = $nearFrameId;
-  return( collectData() );
+  return collectData();
 }
 
 function getNearEvents() {
   global $user, $sortColumn, $sortOrder;
 
   $eventId = $_REQUEST['id'];
+  $NearEvents = array('EventId'=>$eventId);
+
   $event = dbFetchOne('SELECT * FROM Events WHERE Id=?', NULL, array($eventId));
+  if ( !$event ) return $NearEvents;
 
-  parseFilter($_REQUEST['filter']);
+  $filter = ZM\Filter::parse($_REQUEST['filter']);
   parseSort();
-
-  if ( $user['MonitorIds'] )
-    $midSql = ' AND MonitorId IN ('.join( ',', preg_split( '/["\'\s]*,["\'\s]*/', $user['MonitorIds'] ) ).')';
-  else
-    $midSql = '';
-
-  # When listing, it may make sense to list them in descending order.  But when viewing Prev should timewise earlier and Next should be after.
-  if ( $sortColumn == 'E.Id' or $sortColumn == 'E.StartTime' ) {
-    $sortOrder = 'asc';
+  if ( $user['MonitorIds'] ) {
+    $filter = $filter->addTerm(array('cnj'=>'and', 'attr'=>'MonitorId', 'op'=>'IN', 'val'=>$user['MonitorIds']));
   }
 
-  $sql = "SELECT E.Id AS Id, E.StartTime AS StartTime FROM Events AS E INNER JOIN Monitors AS M ON E.MonitorId = M.Id WHERE $sortColumn ".($sortOrder=='asc'?'<=':'>=')." '".$event[$_REQUEST['sort_field']]."'".$_REQUEST['filter']['sql'].$midSql.' AND E.Id<'.$event['Id'] . " ORDER BY $sortColumn ".($sortOrder=='asc'?'desc':'asc');
+  # When listing, it may make sense to list them in descending order.
+  # But when viewing Prev should timewise earlier and Next should be after.
+  if ( $sortColumn == 'E.Id' or $sortColumn == 'E.StartDateTime' ) {
+    $sortOrder = 'ASC';
+  }
+
+  $sql = 'SELECT E.Id AS Id, E.StartDateTime AS StartDateTime FROM Events AS E INNER JOIN Monitors AS M ON E.MonitorId = M.Id WHERE '.$sortColumn.' '.($sortOrder=='ASC'?'<=':'>=').' \''.$event[$_REQUEST['sort_field']].'\' AND ('.$filter->sql().') AND E.Id<'.$event['Id'] . ' ORDER BY '.$sortColumn.' '.($sortOrder=='ASC'?'DESC':'ASC');
   if ( $sortColumn != 'E.Id' ) {
     # When sorting by starttime, if we have two events with the same starttime (diffreent monitors) then we should sort secondly by Id
     $sql .= ', E.Id DESC';
   }
   $sql .= ' LIMIT 1';
   $result = dbQuery($sql);
+  if ( !$result ) {
+    ZM\Error('Failed to load previous event using '.$sql);
+    return $NearEvents;
+  }
+
   $prevEvent = dbFetchNext($result);
 
-  $sql = "SELECT E.Id AS Id, E.StartTime AS StartTime FROM Events AS E INNER JOIN Monitors AS M ON E.MonitorId = M.Id WHERE $sortColumn ".($sortOrder=='asc'?'>=':'<=')." '".$event[$_REQUEST['sort_field']]."'".$_REQUEST['filter']['sql'].$midSql.' AND E.Id>'.$event['Id'] . " ORDER BY $sortColumn $sortOrder";
+  $sql = 'SELECT E.Id AS Id, E.StartDateTime AS StartDateTime FROM Events AS E INNER JOIN Monitors AS M ON E.MonitorId = M.Id WHERE '.$sortColumn .' '.($sortOrder=='ASC'?'>=':'<=').' \''.$event[$_REQUEST['sort_field']]."' AND (".$filter->sql().') AND E.Id>'.$event['Id'] . ' ORDER BY '.$sortColumn.' '.($sortOrder=='ASC'?'ASC':'DESC');
   if ( $sortColumn != 'E.Id' ) {
     # When sorting by starttime, if we have two events with the same starttime (diffreent monitors) then we should sort secondly by Id
     $sql .= ', E.Id ASC';
   }
   $sql .= ' LIMIT 1';
-  $result = dbQuery( $sql );
-  $nextEvent = dbFetchNext( $result );
+  $result = dbQuery($sql);
+  if ( !$result ) {
+    ZM\Error('Failed to load next event using '.$sql);
+    return $NearEvents;
+  }
+  $nextEvent = dbFetchNext($result);
 
-  $result = array( 'EventId'=>$eventId );
   if ( $prevEvent ) {
-    $result['PrevEventId'] = $prevEvent['Id'];
-    $result['PrevEventStartTime'] = $prevEvent['StartTime'];
-    $result['PrevEventDefVideoPath'] = getEventDefaultVideoPath($prevEvent['Id']);
+    $NearEvents['PrevEventId'] = $prevEvent['Id'];
+    $NearEvents['PrevEventStartTime'] = $prevEvent['StartDateTime'];
+    $NearEvents['PrevEventDefVideoPath'] = getEventDefaultVideoPath($prevEvent['Id']);
   } else {
-    $result['PrevEventId'] = $result['PrevEventStartTime'] = $result['PrevEventDefVideoPath'] = 0;
+    $NearEvents['PrevEventId'] = $NearEvents['PrevEventStartTime'] = $NearEvents['PrevEventDefVideoPath'] = 0;
   }
   if ( $nextEvent ) {
-    $result['NextEventId'] = $nextEvent['Id'];
-    $result['NextEventStartTime'] = $nextEvent['StartTime'];
-    $result['NextEventDefVideoPath'] = getEventDefaultVideoPath($nextEvent['Id']);
+    $NearEvents['NextEventId'] = $nextEvent['Id'];
+    $NearEvents['NextEventStartTime'] = $nextEvent['StartDateTime'];
+    $NearEvents['NextEventDefVideoPath'] = getEventDefaultVideoPath($nextEvent['Id']);
   } else {
-    $result['NextEventId'] = $result['NextEventStartTime'] = $result['NextEventDefVideoPath'] = 0;
+    $NearEvents['NextEventId'] = $NearEvents['NextEventStartTime'] = $NearEvents['NextEventDefVideoPath'] = 0;
   }
-  return $result;
-}
+  return $NearEvents;
+} # end function getNearEvents()
 
 ?>
