@@ -74,10 +74,10 @@ class HostController extends AppController {
     $cred_depr = [];
 
     if ( $username && $password ) {
-      ZM\Logger::Debug('Username and password provided, generating access and refresh tokens');
+      ZM\Debug('Username and password provided, generating access and refresh tokens');
       $cred = $this->_getCredentials(true, '', $username); // generate refresh
     } else {
-      ZM\Logger::Debug('Only generating access token');
+      ZM\Debug('Only generating access token');
       $cred = $this->_getCredentials(false, $token); // don't generate refresh
     }
 
@@ -96,7 +96,7 @@ class HostController extends AppController {
       $login_array['credentials'] = $cred_depr[0];
       $login_array['append_password'] = $cred_depr[1];
     } else {
-      ZM\Logger::Debug('Legacy Auth is disabled, not generating auth= credentials');
+      ZM\Debug('Legacy Auth is disabled, not generating auth= credentials');
     }
 
     $login_array['version'] = $ver[0];
@@ -137,7 +137,7 @@ class HostController extends AppController {
   private function _getCredentials($generate_refresh_token=false, $token='', $username='') {
 
     if ( !ZM_OPT_USE_AUTH ) {
-      ZM\Error('OPT_USE_AUTH is turned off. Tokens will be null');
+      ZM\Debug('OPT_USE_AUTH is turned off. Tokens will be null');
       return;
     }
       
@@ -227,7 +227,7 @@ class HostController extends AppController {
 
     if ( $mid ) {
       // Get disk usage for $mid
-      ZM\Logger::Debug("Executing du -s0 $zm_dir_events/$mid | awk '{print $1}'");
+      ZM\Debug("Executing du -s0 $zm_dir_events/$mid | awk '{print $1}'");
       $usage = shell_exec("du -s0 $zm_dir_events/$mid | awk '{print $1}'");
     } else {
       $monitors = $this->Monitor->find('all', array(
