@@ -334,23 +334,34 @@ class CakeEmailTest extends CakeTestCase {
 /**
  * testBuildInvalidData
  *
- * @dataProvider invalidEmails
  * @expectedException SocketException
+ * @expectedExceptionMessage The email set for "_to" is empty.
  * @return void
  */
-	public function testInvalidEmail($value) {
-		$this->CakeEmail->to($value);
+	public function testInvalidEmail() {
+		$this->CakeEmail->to('');
 	}
 
 /**
  * testBuildInvalidData
  *
- * @dataProvider invalidEmails
  * @expectedException SocketException
+ * @expectedExceptionMessage Invalid email set for "_from". You passed "cake.@"
  * @return void
  */
-	public function testInvalidEmailAdd($value) {
-		$this->CakeEmail->addTo($value);
+	public function testInvalidFrom() {
+		$this->CakeEmail->from('cake.@');
+	}
+
+/**
+ * testBuildInvalidData
+ *
+ * @expectedException SocketException
+ * @expectedExceptionMessage Invalid email set for "_to". You passed "1"
+ * @return void
+ */
+	public function testInvalidEmailAdd() {
+		$this->CakeEmail->addTo('1');
 	}
 
 /**
@@ -423,7 +434,7 @@ class CakeEmailTest extends CakeTestCase {
  * @return void
  *
  * @expectedException SocketException
- * @expectedExceptionMessage Invalid email: "fail.@example.com"
+ * @expectedExceptionMessage Invalid email set for "_to". You passed "fail.@example.com"
  */
 	public function testUnsetEmailPattern() {
 		$email = new CakeEmail();
