@@ -30,22 +30,23 @@ require_once('logger.php');
 function dbConnect() {
   global $dbConn;
 
-  $socket = '';
+  $dsn = ZM_DB_TYPE;
   if ( ZM_DB_HOST ) {
     if ( strpos(ZM_DB_HOST, ':') ) {
       // Host variable may carry a port or socket.
       list($host, $portOrSocket) = explode(':', ZM_DB_HOST, 2);
       if ( ctype_digit($portOrSocket) ) {
-        $socket = ':host='.$host . ';port='.$portOrSocket.';';
+        $dsn .= ':host='.$host.';port='.$portOrSocket.';';
       } else {
-        $socket = ':unix_socket='.$portOrSocket.';';
+        $dsn .= ':unix_socket='.$portOrSocket.';';
       }
     } else {
-      $socket = ':host='.ZM_DB_HOST.';';
+      $dsn .= ':host='.ZM_DB_HOST.';';
     }
   } else {
-    $socket = ':host=localhost;';
+    $dsn .= ':host=localhost;';
   }
+  $dsn .= 'dbname='.ZM_DB_NAME;
 
   try {
     $dbOptions = null;
@@ -55,15 +56,16 @@ function dbConnect() {
         PDO::MYSQL_ATTR_SSL_KEY  => ZM_DB_SSL_CLIENT_KEY,
         PDO::MYSQL_ATTR_SSL_CERT => ZM_DB_SSL_CLIENT_CERT,
       );
-      $dbConn = new PDO(ZM_DB_TYPE.$socket.'dbname='.ZM_DB_NAME, ZM_DB_USER, ZM_DB_PASS, $dbOptions);
+      $dbConn = new PDO($dsn, ZM_DB_USER, ZM_DB_PASS, $dbOptions);
     } else {
-      $dbConn = new PDO(ZM_DB_TYPE.$socket.'dbname='.ZM_DB_NAME, ZM_DB_USER, ZM_DB_PASS);
+      $dbConn = new PDO($dsn, ZM_DB_USER, ZM_DB_PASS);
     }
 
     $dbConn->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
     $dbConn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
   } catch(PDOException $ex) {
-    echo 'Unable to connect to ZM db.' . $ex->getMessage();
+    global $error_message;
+    $error_message = "Unable to connect to ZM db using dsn $dsn<br/><br/>".$ex->getMessage();
     error_log('Unable to connect to ZM DB ' . $ex->getMessage());
     $dbConn = null;
   }
@@ -71,7 +73,8 @@ function dbConnect() {
 }  // end function dbConnect
 
 if ( !dbConnect() ) {
-  ZM\Fatal("Failed db connection to $socket");
+  include('views/no_database_connection.php');
+  exit();
 }
 
 function dbDisconnect() {
@@ -102,17 +105,17 @@ function dbLog($sql, $update=false) {
   global $dbLogLevel;
   $noExecute = $update && ($dbLogLevel >= DB_LOG_DEBUG);
   if ( $dbLogLevel > DB_LOG_OFF )
-    ZM\Logger::Debug( "SQL-LOG: $sql".($noExecute?' (not executed)':'') );
+    ZM\Debug( "SQL-LOG: $sql".($noExecute?' (not executed)':'') );
   return( $noExecute );
 }
 
 function dbError($sql) {
   global $dbConn;
   $error = $dbConn->errorInfo();
-  if ( ! $error[0] )
+  if (!$error[0])
     return '';
 
-  $message = "SQL-ERR '".implode("\n",$dbConn->errorInfo())."', statement was '".$sql."'";
+  $message = "SQL-ERR '".implode("\n", $dbConn->errorInfo())."', statement was '".$sql."'";
   ZM\Error($message);
   return $message;
 }
@@ -127,23 +130,23 @@ function dbEscape( $string ) {
 
 function dbQuery($sql, $params=NULL, $debug = false) {
   global $dbConn;
-  if ( dbLog($sql, true) )
+  if (dbLog($sql, true))
     return;
   $result = NULL;
   try {
-    if ( isset($params) ) {
-      if ( ! $result = $dbConn->prepare($sql) ) {
+    if (isset($params)) {
+      if (!$result = $dbConn->prepare($sql)) {
         ZM\Error("SQL: Error preparing $sql: " . $pdo->errorInfo);
         return NULL;
       }
 
-      if ( ! $result->execute($params) ) {
+      if (!$result->execute($params)) {
         ZM\Error("SQL: Error executing $sql: " . print_r($result->errorInfo(), true));
         return NULL;
       }
     } else {
       if ( defined('ZM_DB_DEBUG') or $debug ) {
-				ZM\Logger::Debug("SQL: $sql values:" . ($params?implode(',',$params):''));
+				ZM\Debug("SQL: $sql values:" . ($params?implode(',',$params):''));
       }
       $result = $dbConn->query($sql);
       if ( ! $result ) {
@@ -152,10 +155,7 @@ function dbQuery($sql, $params=NULL, $debug = false) {
       }
     }
     if ( defined('ZM_DB_DEBUG') or $debug ) {
-      if ( $params )
-        ZM\Logger::Debug("SQL: $sql " . implode(',',$params) . ' rows: '.$result->rowCount());
-      else
-        ZM\Logger::Debug("SQL: $sql: rows:" . $result->rowCount());
+      ZM\Debug('SQL: '.$sql.' '.($params?implode(',',$params):'').' rows: '.$result->rowCount());
     }
   } catch(PDOException $e) {
     ZM\Error("SQL-ERR '".$e->getMessage()."', statement was '".$sql."' params:" . ($params?implode(',',$params):''));
