@@ -19,6 +19,7 @@
 //
 //
 // ZoneMinder Hungarian Translation by szimszon at oregpreshaz dot eu, robi
+// version: 0.9 - 2021.05.25. - frissítés 1.36.1-hez (gerazo)
 // version: 0.8 - 2013.08.16. - frissítés 1.26.0-hoz (robi)
 // version: 0.7 - 2013.05.12. - frissítés 1.25.0-hoz (robi)
 // version: 0.6 - 2009.06.21. - frissítés 1.24.2-höz (robi)
@@ -115,14 +116,14 @@ define( "STRF_FMT_DATETIME_SHORTER", "%m.%d. %H:%M:%S" );       // Strftime shor
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'          => '24 bites szín',
-    '32BitColour'          => '32 bit colour',          // Added - 2015-04-18
+    '32BitColour'          => '32 bites szín',
     '8BitGrey'             => '8 bit szürkeárnyalat',
     'Action'               => 'Művelet',
     'Actual'               => 'Valós',
     'AddNewControl'        => 'Új vezérlés',
     'AddNewMonitor'        => 'Új kamera',
-    'AddNewServer'         => 'Add New Server',         // Added - 2018-08-30
-    'AddNewStorage'        => 'Add New Storage',        // Added - 2018-08-30
+    'AddNewServer'         => 'Új szerver',
+    'AddNewStorage'        => 'Új tároló',
     'AddNewUser'           => 'Új felhasználó',
     'AddNewZone'           => 'Új zóna',
     'Alarm'                => 'Riadó',
@@ -133,11 +134,11 @@ $SLANG = array(
     'AlarmMaximumFPS'      => 'Maximális FPS riasztott állapotban',
     'AlarmPx'              => 'Riasztó képpont',
     'AlarmRGBUnset'        => 'Be kell állítani egy RGB színt a riasztáshoz',
-    'AlarmRefImageBlendPct'=> 'Alarm Reference Image Blend %ge', // Added - 2015-04-18
+    'AlarmRefImageBlendPct'=> 'Változás a referenciaképtől %-ban riasztásnál',
     'Alert'                => 'Figyelem',
     'All'                  => 'Mind',
-    'AnalysisFPS'          => 'Analysis FPS',           // Added - 2015-07-22
-    'AnalysisUpdateDelay'  => 'Analysis Update Delay',  // Added - 2015-07-23
+    'AnalysisFPS'          => 'Elemzés FPS',
+    'AnalysisUpdateDelay'  => 'Elemzés frissítésének késleltetése',
     'Apply'                => 'Alkalmaz',
     'ApplyingStateChange'  => 'Állapot váltása...',
     'ArchArchived'         => 'Csak archivált',
@@ -152,28 +153,28 @@ $SLANG = array(
     'AttrCause'            => 'Okozó',
     'AttrDiskBlocks'       => 'Tárhely blokk',
     'AttrDiskPercent'      => 'Tárhely százalék',
-    'AttrDiskSpace'        => 'Disk Space',             // Added - 2018-08-30
+    'AttrDiskSpace'        => 'Tárhely',
     'AttrDuration'         => 'Időtartam',
-    'AttrEndDate'          => 'End Date',               // Added - 2018-08-30
-    'AttrEndDateTime'      => 'End Date/Time',          // Added - 2018-08-30
-    'AttrEndTime'          => 'End Time',               // Added - 2018-08-30
-    'AttrEndWeekday'       => 'End Weekday',            // Added - 2018-08-30
-    'AttrFilterServer'     => 'Server Filter is Running On', // Added - 2018-08-30
+    'AttrEndDate'          => 'Vége dátuma',
+    'AttrEndDateTime'      => 'Vége dátuma/ideje',
+    'AttrEndTime'          => 'Vége ideje',
+    'AttrEndWeekday'       => 'Vége hét napja',
+    'AttrFilterServer'     => 'Szűrő ezen a szerveren fut',
     'AttrFrames'           => 'Képkocka',
     'AttrId'               => 'Azonosító',
     'AttrMaxScore'         => 'Max. érték',
     'AttrMonitorId'        => 'Kamera azonosító',
     'AttrMonitorName'      => 'Kamera név',
-    'AttrMonitorServer'    => 'Server Monitor is Running On', // Added - 2018-08-30
+    'AttrMonitorServer'    => 'Kamera ezen a szerveren fut',
     'AttrName'             => 'Név',
     'AttrNotes'            => 'Megjegyzés',
-    'AttrStartDate'        => 'Start Date',             // Added - 2018-08-30
-    'AttrStartDateTime'    => 'Start Date/Time',        // Added - 2018-08-30
-    'AttrStartTime'        => 'Start Time',             // Added - 2018-08-30
-    'AttrStartWeekday'     => 'Start Weekday',          // Added - 2018-08-30
-    'AttrStateId'          => 'Run State',              // Added - 2018-08-30
-    'AttrStorageArea'      => 'Storage Area',           // Added - 2018-08-30
-    'AttrStorageServer'    => 'Server Hosting Storage', // Added - 2018-08-30
+    'AttrStartDate'        => 'Kezdés dátuma',
+    'AttrStartDateTime'    => 'Kezdés dátuma/ideje',
+    'AttrStartTime'        => 'Kezdés ideje',
+    'AttrStartWeekday'     => 'Kezdés hét napja',
+    'AttrStateId'          => 'Futási állapot',
+    'AttrStorageArea'      => 'Tárterület',
+    'AttrStorageServer'    => 'Tárterület szervere',
     'AttrSystemLoad'       => 'Rendszerterhelés',
     'AttrTotalScore'       => 'Összérték',
     'Auto'                 => 'Auto',
@@ -184,23 +185,23 @@ $SLANG = array(
     'BackgroundFilter'     => 'Szűrő automatikus futtatása a háttérben',
     'BadAlarmFrameCount'   => 'Riasztáshoz szükséges képkockák száma legyen legalább 1',
     'BadAlarmMaxFPS'       => 'Maximális FPS riasztott állapotban legyen megadva',
-    'BadAnalysisFPS'       => 'Analysis FPS must be a positive integer or floating point value', // Added - 2015-07-22
-    'BadAnalysisUpdateDelay'=> 'Analysis update delay must be set to an integer of zero or more', // Added - 2015-07-23
+    'BadAnalysisFPS'       => 'Elemzés FPS-nek pozitív egész vagy tört számnak kell lennie',
+    'BadAnalysisUpdateDelay'=> 'Elemzés frissítésének késleltetését 0 vagy nagyobb egész számra kell állítani',
     'BadChannel'           => 'A csatorna száma legyen legalább 0',
-    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2015-04-18
+    'BadColours'           => 'A cél színét helyesen kell megadni',
     'BadDevice'            => 'Az eszköz elérése valós legyen',
     'BadFPSReportInterval' => 'Az FPS naplózásának gyakorisága legyen legalább 0',
     'BadFormat'            => 'A típus 0 vagy nagyobb egész szám legyen',
     'BadFrameSkip'         => 'Az eldobott képkockák száma legyen legalább 0',
     'BadHeight'            => 'A képmagasság legyen érvényes érték képpontban megadva',
     'BadHost'              => 'A hoszt legyen valós IP cím vagy hosztnév http:// nélkül',
-    'BadImageBufferCount'  => 'A képkockák száma a pufferben legyen legalább 10',
+    'BadImageBufferCount'  => 'A képkockák száma a pufferben legyen legalább 2',
     'BadLabelX'            => 'A cimke X koordinátája legyen legalább 0',
     'BadLabelY'            => 'A cimke Y koordinátája legyen legalább 0',
     'BadMaxFPS'            => 'Maximális FPS nyugalmi állapotban legyen megadva',
-    'BadMotionFrameSkip'   => 'Motion Frame skip count must be an integer of zero or more',
+    'BadMotionFrameSkip'   => 'A mozgásnál eldobott képkockák száma legyen 0 vagy nagyobb egész',
     'BadNameChars'         => 'A név csak betűket, számokat, plusz-, kötő-, és aláhúzásjelet tartalmazhat',
-    'BadPalette'           => 'A szín-palettának válasszin egy helyes értéket',
+    'BadPalette'           => 'A szín-palettának válasszon egy helyes értéket',
     'BadPath'              => 'A kép elérési útvonala helytelen',
     'BadPort'              => 'A portszám helytelen',
     'BadPostEventCount'    => 'Az esemény utáni képkockák száma legyen legalább 0',
@@ -208,11 +209,11 @@ $SLANG = array(
     'BadRefBlendPerc'      => 'Változás a referenciaképtől legyen legalább 1',
     'BadSectionLength'     => 'Fix időtartamú esemény hossza legyen legalább 30',
     'BadSignalCheckColour' => 'Szín a jel kimaradásakor legyen egy érvényes HTML szín-kód',
-    'BadSourceType'        => 'Source Type \"Web Site\" requires the Function to be set to \"Monitor\"', // Added - 2018-08-30
+    'BadSourceType'        => 'A \"Weboldal\" forrás típushoz szükséges, hogy a Funkció \"Csak monitorozás\"-ra legyen állítva',
     'BadStreamReplayBuffer'=> 'Folyam visszajátszó puffer legyen legalább 0',
     'BadWarmupCount'       => 'Bemelegítő képkockák száma legyen legalább 0',
     'BadWebColour'         => 'Szín az idővonal ablakban legyen egy érvényes HTML szín-kód',
-    'BadWebSitePath'       => 'Please enter a complete website url, including the http:// or https:// prefix.', // Added - 2018-08-30
+    'BadWebSitePath'       => 'Kérem, teljes weboldal URL-t adjon meg, beleértve a http:// vagy https:// előtagot.',
     'BadWidth'             => 'A képszélesség legyen érvényes érték képpontban megadva',
     'Bandwidth'            => 'Sávszélesség',
     'BandwidthHead'        => 'sávszélességre',
@@ -220,9 +221,9 @@ $SLANG = array(
     'BlobSizes'            => 'Blob méretek',
     'Blobs'                => 'Blob-ok',
     'Brightness'           => 'Fényerő',
-    'Buffer'               => 'Buffer',                 // Added - 2015-04-18
+    'Buffer'               => 'Puffer',
     'Buffers'              => 'Pufferek',
-    'CSSDescription'       => 'Change the default css for this computer', // Added - 2015-04-18
+    'CSSDescription'       => 'Alapértelmezett CSS megváltoztatása ezen a gépen',
     'CanAutoFocus'         => 'Van autofókusza',
     'CanAutoGain'          => 'Van AGC-je',
     'CanAutoIris'          => 'Van autoírisze',
@@ -248,9 +249,9 @@ $SLANG = array(
     'CanMoveRel'           => 'Relatíven tud mozogni',
     'CanPan'               => 'Tud jobb-bal mozgást' ,
     'CanReset'             => 'Tud alaphelyzetbe jönni',
-	'CanReboot'             => 'Can Reboot',
+	'CanReboot'             => 'Tud újraindulni',
     'CanSetPresets'        => 'Tud menteni profilokat',
-    'CanSleep'             => 'Tud phihenő üzemmódot',
+    'CanSleep'             => 'Tud pihenő üzemmódot',
     'CanTilt'              => 'Tud fel-le mozgást',
     'CanWake'              => 'Tud feléledni',
     'CanWhite'             => 'Van fehér szintje',
@@ -265,9 +266,9 @@ $SLANG = array(
     'Cancel'               => 'Mégsem',
     'CancelForcedAlarm'    => 'Kézi riasztás megszűntetése',
     'CaptureHeight'        => 'Képmagasság',
-    'CaptureMethod'        => 'Digitalizálás módszere',
-    'CapturePalette'       => 'Digitalizálás szín-palettája',
-    'CaptureResolution'    => 'Capture Resolution',     // Added - 2015-04-18
+    'CaptureMethod'        => 'Beolvasás módszere',
+    'CapturePalette'       => 'Beolvasás szín-palettája',
+    'CaptureResolution'    => 'Beolvasás felbontása',
     'CaptureWidth'         => 'Képszélesség',
     'Cause'                => 'Okozó',
     'CheckMethod'          => 'A riasztás figyelésének módja',
@@ -277,12 +278,12 @@ $SLANG = array(
     'ChooseLogSelection'   => 'Válasszon naplót',
     'ChoosePreset'         => 'Válasszon profilt',
     'Clear'                => 'Törlés',
-    'CloneMonitor'         => 'Clone',                  // Added - 2018-08-30
+    'CloneMonitor'         => 'Klónozás',
     'Close'                => 'Bezárás',
     'Colour'               => 'Szín',
     'Command'              => 'Parancs',
     'Component'            => 'Komponens',
-    'ConcurrentFilter'     => 'Run filter concurrently', // Added - 2018-08-30
+    'ConcurrentFilter'     => 'Szűrő párhuzamosított futtatása',
     'Config'               => 'Beállítás',
     'ConfiguredFor'        => 'Beállítva',
     'ConfirmDeleteEvents'  => 'Biztos benne, hogy törli a kiválasztott eseményeket?',
@@ -300,7 +301,7 @@ $SLANG = array(
     'ControlDevice'        => 'Vezérlő eszköz',
     'ControlType'          => 'Vezérlés típusa',
     'Controllable'         => 'Vezérelhető',
-    'Current'              => 'Current',                // Added - 2015-04-18
+    'Current'              => 'Aktuális',
     'Cycle'                => 'Ciklikus nézet',
     'CycleWatch'           => 'Ciklikus nézet',
     'DateTime'             => 'Dátum/Idő', 
@@ -309,15 +310,15 @@ $SLANG = array(
     'DefaultRate'          => 'Alapértelmezett sebesség',
     'DefaultScale'         => 'Alapértelmezett méret',
     'DefaultView'          => 'Alapértelmezett nézet',
-    'Deinterlacing'        => 'Deinterlacing',          // Added - 2015-04-18
-    'Delay'                => 'Delay',                  // Added - 2015-04-18
+    'Deinterlacing'        => 'Váltottsorosság megszűntetése',
+    'Delay'                => 'Késleltetés',
     'Delete'               => 'Törlés',
     'DeleteAndNext'        => 'Törlés &amp;<br>következő',
     'DeleteAndPrev'        => 'Törlés &amp;<br>előző',
     'DeleteSavedFilter'    => 'Mentett szűrő törlése',
     'Description'          => 'Leírás',
     'DetectedCameras'      => 'Érzékelt kamerák',
-    'DetectedProfiles'     => 'Detected Profiles',      // Added - 2015-04-18
+    'DetectedProfiles'     => 'Érzékelt profilok',
     'Device'               => 'Eszköz',
     'DeviceChannel'        => 'Eszköz csatornája',
     'DeviceFormat'         => 'Eszköz formátuma',
@@ -329,7 +330,7 @@ $SLANG = array(
     'Disk'                 => 'Tárhely',
     'Display'              => 'Megjelenés',
     'Displaying'           => 'Megjelenítés',
-    'DoNativeMotionDetection'=> 'Do Native Motion Detection', // Added - 2015-04-18
+    'DoNativeMotionDetection'=> 'Natív mozgásérzékelés',
     'Donate'               => 'Kérem támogasson',
     'DonateAlready'        => 'Nem, én már támogattam',
     'DonateEnticement'     => 'Ön már jó ideje használja a ZoneMindert, és reméljük hasznos eszköznek tartja háza vagy munkahelye biztonságában. Bár a ZoneMinder egy szabad, nyílt forráskódú termék és az is marad, a fejlesztése pénzbe kerül. Ha van lehetősége támogatni a jövőbeni fejlesztéseket és az új funkciókat kérem, tegye meg. A támogatás teljesen önkéntes, de nagyon megbecsült és mértéke is tetszőleges.<br><br>Ha támogatni szertne, kérem, válasszon az alábbi lehetőségekből vagy látogassa meg a https://zoneminder.com/donate/ oldalt.<br><br>Köszönjük, hogy használja a ZoneMinder-t és ne felejtse el meglátogatni a fórumokat a ZoneMinder.com oldalon támogatásért és ötletekért, hogy a jövőben is még jobban ki tudja használni a ZoneMinder lehetőségeit.',
@@ -340,11 +341,11 @@ $SLANG = array(
     'DonateRemindWeek'     => 'Nem most, figyelmeztessen egy hét múlva',
     'DonateYes'            => 'Igen, most szeretném támogatni',
     'Download'             => 'Letöltés',
-    'DownloadVideo'        => 'Download Video',         // Added - 2018-08-30
+    'DownloadVideo'        => 'Videó letöltése',
     'DuplicateMonitorName' => 'Kameranév duplikálás',
     'Duration'             => 'Időtartam',
     'Edit'                 => 'Szerkesztés',
-    'EditLayout'           => 'Edit Layout',            // Added - 2018-08-30
+    'EditLayout'           => 'Elrendezés szerkesztése',
     'Email'                => 'E-mail',
     'EnableAlarms'         => 'Riasztások engedélyezése',
     'Enabled'              => 'Engedélyezve',
@@ -361,7 +362,7 @@ $SLANG = array(
     'Events'               => 'Események',
     'Exclude'              => 'Kizárás',
     'Execute'              => 'Végrehajtás',
-    'Exif'                 => 'Embed EXIF data into image', // Added - 2018-08-30
+    'Exif'                 => 'EXIF adatok képbeillesztése',
     'Export'               => 'Exportálás',
     'ExportDetails'        => 'Esemény adatainak exportálása',
     'ExportFailed'         => 'Az exportálás sikertelen',
@@ -384,17 +385,17 @@ $SLANG = array(
     'Feed'                 => 'Folyam',
     'Ffmpeg'               => 'ffmpeg',
     'File'                 => 'Fájl',
-    'Filter'               => 'Filter',                 // Added - 2015-04-18
+    'Filter'               => 'Szűrő',
     'FilterArchiveEvents'  => 'Minden találat archiválása',
     'FilterDeleteEvents'   => 'Minden találat törlése',
     'FilterEmailEvents'    => 'Minden találat adatainak küldése E-mailben',
     'FilterExecuteEvents'  => 'Parancs futtatása minden találaton',
-    'FilterLog'            => 'Filter log',             // Added - 2015-04-18
+    'FilterLog'            => 'Szűrési napló',
     'FilterMessageEvents'  => 'Minden találat adatainak üzenése',
-    'FilterMoveEvents'     => 'Move all matches',       // Added - 2018-08-30
+    'FilterMoveEvents'     => 'Minden találat mozgatása',
     'FilterPx'             => 'Szűrt képkockák',
     'FilterUnset'          => 'Meg kell adnod a szűrő szélességét és magasságát',
-    'FilterUpdateDiskSpace'=> 'Update used disk space', // Added - 2018-08-30
+    'FilterUpdateDiskSpace'=> 'Használt tárterület frissítése',
     'FilterUploadEvents'   => 'Minden találat feltöltése',
     'FilterVideoEvents'    => 'Videó készítése minden találatról',
     'Filters'              => 'Szűrők',
@@ -413,13 +414,13 @@ $SLANG = array(
     'Frame'                => 'Képkocka',
     'FrameId'              => 'Képkocka azonosító',
     'FrameRate'            => 'FPS',
-    'FrameSkip'            => 'Képkocka kihagyás',
+    'FrameSkip'            => 'Képkocka-kihagyás',
     'Frames'               => 'Képkocka',
     'Func'                 => 'Funk.',
     'Function'             => 'Funkció',
     'Gain'                 => 'Erősítés',
     'General'              => 'Általános',
-    'GenerateDownload'     => 'Generate Download',      // Added - 2018-08-30
+    'GenerateDownload'     => 'Letöltés készítése',
     'GenerateVideo'        => 'Videó készítés',
     'GeneratingVideo'      => 'Videó készítése folyamatban',
     'GoToZoneMinder'       => 'Ellenőrzés a ZoneMinder.com-on',
@@ -440,7 +441,7 @@ $SLANG = array(
     'High'                 => 'Magas',
     'HighBW'               => 'Magas<br>sávszél',
     'Home'                 => 'Alapba',
-    'Hostname'             => 'Hostname',               // Added - 2018-08-30
+    'Hostname'             => 'Gépnév',
     'Hour'                 => 'Órában',
     'Hue'                  => 'Színárnyalat',
     'Id'                   => 'Az.',
@@ -465,7 +466,7 @@ $SLANG = array(
     'Line'                 => 'Sor',
     'LinkedMonitors'       => 'Összefüggés más kamerákkal<br>(jelölés Ctrl+kattintással)',
     'List'                 => 'Lista',
-    'ListMatches'          => 'List Matches',           // Added - 2018-08-30
+    'ListMatches'          => 'Találatok listázása',
     'Load'                 => 'Terhelés',
     'Local'                => 'Helyi',
     'Log'                  => 'Napló',
@@ -543,7 +544,7 @@ $SLANG = array(
     'MinZoomSpeed'         => 'Min. zoom sebesség',
     'MinZoomStep'          => 'Min. zoom lépték',
     'Misc'                 => 'Egyéb',
-    'Mode'                 => 'Mode',                   // Added - 2015-04-18
+    'Mode'                 => 'Mód',
     'Monitor'              => 'Kamera',
     'MonitorIds'           => 'Kamera&nbsp;azonosítók',
     'MonitorPreset'        => 'Előre beállított kameraprofilok',
@@ -552,10 +553,10 @@ $SLANG = array(
     'MonitorProbeIntro'    => 'Az alábbi listában találhatók az automatikusan érzékelt analóg és hálózati kamerákat, illetve azt, hogy közülük melyik van használatban, vagy kiválasztható.<br/><br/>Válasszon egyet az alábbi listából.<br/><br/>Figyelem: nem biztos, hogy minden kamerát lehet automatikusan érzékelni. Az itt kiválasztott kamara adatai felülírhatják azokat, amelyeket már ehhez a monitorhoz beállított.<br/><br/>',
     'Monitors'             => 'Kamerák',
     'Montage'              => 'Többkamerás nézet',
-    'MontageReview'        => 'Montage Review',         // Added - 2018-08-30
+    'MontageReview'        => 'Montázs nézet',
     'Month'                => 'Hónapban',
     'More'                 => 'Több',
-    'MotionFrameSkip'      => 'Motion Frame Skip',
+    'MotionFrameSkip'      => 'Képkocka-kihagyás mozgásnál',
     'Move'                 => 'Mozgás',
     'Mtg2widgrd'           => '2 oszlopban',
     'Mtg3widgrd'           => '3 oszlopban',
@@ -579,7 +580,7 @@ $SLANG = array(
     'Next'                 => 'Következő',
     'No'                   => 'Nem',
     'NoDetectedCameras'    => 'Nem érzékelhetőek kamerák',
-    'NoDetectedProfiles'   => 'No Detected Profiles',   // Added - 2018-08-30
+    'NoDetectedProfiles'   => 'Nem érzékelhetőek profilok',
     'NoFramesRecorded'     => 'Nincs rögzített képkocka ehhez az eseményhez',
     'NoGroup'              => 'Nincs csoport',
     'NoSavedFilters'       => 'Nincs mentett szűrő',
@@ -591,15 +592,15 @@ $SLANG = array(
     'NumPresets'           => 'Profilok száma',
     'Off'                  => 'Ki',
     'On'                   => 'Be',
-    'OnvifCredentialsIntro'=> 'Please supply user name and password for the selected camera.<br/>If no user has been created for the camera then the user given here will be created with the given password.<br/><br/>', // Added - 2015-04-18
-    'OnvifProbe'           => 'ONVIF',                  // Added - 2015-04-18
-    'OnvifProbeIntro'      => 'The list below shows detected ONVIF cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2015-04-18
+    'OnvifCredentialsIntro'=> 'Kérem, adjon meg felhasználónevet és jelszót a választott kamerához.<br/>Ha nem készült felhasználó a kamerához, akkor az itt megadott felhasználó és jelszó készül el majd hozzá.<br/><br/>',
+    'OnvifProbe'           => 'ONVIF',
+    'OnvifProbeIntro'      => 'Az alábbi lista az érzékelt ONVIF kamerákat mutatja és azt, hogy már használják-e őket vagy még választhatóak.<br/><br/>Válassza ki a kívánt bejegyzést az alábbi listából.<br/><br/>Fontos, hogy nem minden kamerát lehet érzékelni, illetve egy kiválasztása felülírhatja a kamerához eddig beállított értékeket.<br/><br/>',
     'OpEq'                 => 'egyenlő',
     'OpGt'                 => 'nagyobb mint',
     'OpGtEq'               => 'nagyobb van egyenlő',
     'OpIn'                 => 'beállítva',
-    'OpIs'                 => 'is',                     // Added - 2018-08-30
-    'OpIsNot'              => 'is not',                 // Added - 2018-08-30
+    'OpIs'                 => 'az egy',
+    'OpIsNot'              => 'az nem',
     'OpLt'                 => 'kisebb mint',
     'OpLtEq'               => 'kisebb vagy egyenlő',
     'OpMatches'            => 'találatok',
@@ -609,7 +610,7 @@ $SLANG = array(
     'Open'                 => 'Megnyitás',
     'OptionHelp'           => 'Beállítási segítség',
     'OptionRestartWarning' => 'Ez a beállítás nem tud érvénybe lépni miközben az élő rendszer fut.\nHa végzett minden beállítással, kérem, indítsa újra a ZoneMinder szolgáltatást.',
-    'OptionalEncoderParam' => 'Optional Encoder Parameters', // Added - 2018-08-30
+    'OptionalEncoderParam' => 'Opcionális tömörítési paraméterek',
     'Options'              => 'Beállítások',
     'OrEnterNewName'       => 'vagy új néven:',
     'Order'                => 'Sorrend',
@@ -634,7 +635,7 @@ $SLANG = array(
     'Play'                 => 'Lejátszás',
     'PlayAll'              => 'Mind lejátszása',
     'PleaseWait'           => 'Kérlek várj...',
-    'Plugins'              => 'Plugins',                // Added - 2015-04-18
+    'Plugins'              => 'Pluginek',
     'Point'                => 'Pont',
     'PostEventImageBuffer' => 'Esemény utáni képkockák a pufferben',
     'PreEventImageBuffer'  => 'Esemény elötti képkockák a pufferben',
@@ -643,17 +644,17 @@ $SLANG = array(
     'Presets'              => 'Előre beállított profilok',
     'Prev'                 => 'Előző',
     'Probe'                => 'Érzékelés',
-    'ProfileProbe'         => 'Stream Probe',           // Added - 2015-04-18
-    'ProfileProbeIntro'    => 'The list below shows the existing stream profiles of the selected camera .<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that ZoneMinder cannot configure additional profiles and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2015-04-18
-    'Progress'             => 'Progress',               // Added - 2015-04-18
-    'Protocol'             => 'Protocol',
-    'RTSPDescribe'         => 'Use RTSP Response Media URL', // Added - 2018-08-30
-    'RTSPTransport'        => 'RTSP Transport Protocol', // Added - 2018-08-30
+    'ProfileProbe'         => 'Adatfolyam érzékelése',
+    'ProfileProbeIntro'    => 'Az alábbi lista a kiválaszott kamera meglévő adatfolyam-profiljait mutatja.<br/><br/>Válassza ki a kívánt opciót az alábbi listából.<br/><br/>Fontos, hogy a ZoneMinder nem tud új profilokat létrehozni, illetve egy kamera kiválasztásával az ehhez eddig beállított értékek felülíródnak.<br/><br/>',
+    'Progress'             => 'Folyamat',
+    'Protocol'             => 'Protokoll',
+    'RTSPDescribe'         => 'RTSP válasz média URL használata',
+    'RTSPTransport'        => 'RTSP átviteli protokoll',
     'Rate'                 => 'FPS',
     'Real'                 => 'Valós',
-    'RecaptchaWarning'     => 'Your reCaptcha secret key is invalid. Please correct it, or reCaptcha will not work', // Added - 2018-08-30
+    'RecaptchaWarning'     => 'A reCaptcha kulcsa nem érvényes. Kérem javítsa vagy a reCaptcha nem fog működni',
     'Record'               => 'Felvétel',
-    'RecordAudio'          => 'Whether to store the audio stream when saving an event.', // Added - 2018-08-30
+    'RecordAudio'          => 'Tároljuk-e a hangot, amikor elmentünk egy eseményt.',
     'RefImageBlendPct'     => 'Változás a referenciaképtől %-ban',
     'Refresh'              => 'Frissítés',
     'Remote'               => 'Hálózati',
@@ -669,7 +670,7 @@ $SLANG = array(
     'ReplayAll'            => 'Mindet',
     'ReplayGapless'        => 'Szünet nélkülieket',
     'ReplaySingle'         => 'Egyenként',
-    'ReportEventAudit'     => 'Audit Events Report',    // Added - 2018-08-30
+    'ReportEventAudit'     => 'Jelentés audit eseményekről',
     'Reset'                => 'Alapértékre',
     'ResetEventCounts'     => 'Eseményszámláló nullázása',
     'Restart'              => 'A szolgáltatás újraindítása',
@@ -688,7 +689,7 @@ $SLANG = array(
     'Save'                 => 'Mentés',
     'SaveAs'               => 'Mentés erre:',
     'SaveFilter'           => 'Szűrő mentése',
-    'SaveJPEGs'            => 'Save JPEGs',             // Added - 2018-08-30
+    'SaveJPEGs'            => 'JPEG mentése',
     'Scale'                => 'Méret',
     'Score'                => 'Pontszám',
     'Secs'                 => 'mp.',
@@ -705,7 +706,7 @@ $SLANG = array(
     'ShowFilterWindow'     => 'Szűrőablak megjelenítése',
     'ShowTimeline'         => 'Idővonal megjelenítése',
     'SignalCheckColour'    => 'Szín a jel kimaradásakor',
-    'SignalCheckPoints'    => 'Signal Check Points',    // Added - 2018-08-30
+    'SignalCheckPoints'    => 'Pontszám a jel kimaradásakor',
     'Size'                 => 'Fájlméret',
     'SkinDescription'      => 'Alapértelmezett felület ebben a böngészőben',
     'Sleep'                => 'Alvás',
@@ -721,14 +722,14 @@ $SLANG = array(
     'SpeedLow'             => 'Alacsony sebesség',
     'SpeedMedium'          => 'Közepes sebesség',
     'SpeedTurbo'           => 'Turbó sebesség',
-    'Start'                => 'Indít',
+    'Start'                => 'Indítás',
     'State'                => 'Állapot',
     'Stats'                => 'Statisztikák',
     'Status'               => 'Státusz',
-    'StatusConnected'      => 'Capturing',              // Added - 2018-08-30
-    'StatusNotRunning'     => 'Not Running',            // Added - 2018-08-30
-    'StatusRunning'        => 'Not Capturing',          // Added - 2018-08-30
-    'StatusUnknown'        => 'Unknown',                // Added - 2018-08-30
+    'StatusConnected'      => 'Felvétel',
+    'StatusNotRunning'     => 'Nem fut',
+    'StatusRunning'        => 'Nincs felvétel',
+    'StatusUnknown'        => 'Ismeretlen',
     'Step'                 => 'Ugrás',
     'StepBack'             => 'Visszalépés',
     'StepForward'          => 'Előrelépés',
@@ -737,16 +738,16 @@ $SLANG = array(
     'StepNone'             => 'Nincs ugrás',
     'StepSmall'            => 'Kis ugrás',
     'Stills'               => 'Állóképek',
-    'Stop'                 => 'A szolgáltatás leállítása',
+    'Stop'                 => 'Leállítás',
     'Stopped'              => 'Leállítva',
-    'StorageArea'          => 'Storage Area',           // Added - 2018-08-30
-    'StorageScheme'        => 'Scheme',                 // Added - 2018-08-30
+    'StorageArea'          => 'Tárterület',
+    'StorageScheme'        => 'Séma',
     'Stream'               => 'Élő folyam',
     'StreamReplayBuffer'   => 'Képkockák száma a pufferben visszajátszáskor',
     'Submit'               => 'Küldés',
     'System'               => 'Rendszer',
     'SystemLog'            => 'Rendszernapló',
-    'TargetColorspace'     => 'Target colorspace',      // Added - 2015-04-18
+    'TargetColorspace'     => 'Cél színtér',
     'Tele'                 => 'Táv',
     'Thumbnail'            => 'Előnézet',
     'Tilt'                 => 'Fel-le mozgás',
@@ -760,7 +761,7 @@ $SLANG = array(
     'TimelineTip4'         => 'Használja az alábbi gombokat hogy az időskálát csúsztassa, vagy kicsinyítse.',
     'Timestamp'            => 'Időbélyeg',
     'TimestampLabelFormat' => 'Időbélyeg formátuma',
-    'TimestampLabelSize'   => 'Font Size',              // Added - 2018-08-30
+    'TimestampLabelSize'   => 'Betű mérete',
     'TimestampLabelX'      => 'Elhelyezés X pozició',
     'TimestampLabelY'      => 'Elhelyezés Y pozició',
     'Today'                => 'Ma',
@@ -785,13 +786,13 @@ $SLANG = array(
     'UseFilter'            => 'Szűrőt használ',
     'UseFilterExprsPost'   => '&nbsp;szürés&nbsp; használata', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => '&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
-    'UsedPlugins'          => 'Used Plugins',           // Added - 2015-04-18
+    'UsedPlugins'          => 'Használt pluginek',
     'User'                 => 'Felhasználó',
     'Username'             => 'Felhasználónév',
     'Users'                => 'Felhasználók',
-    'V4L'                  => 'V4L',                    // Added - 2015-04-18
-    'V4LCapturesPerFrame'  => 'Captures Per Frame',     // Added - 2015-04-18
-    'V4LMultiBuffer'       => 'Multi Buffering',        // Added - 2015-04-18
+    'V4L'                  => 'V4L',
+    'V4LCapturesPerFrame'  => 'Beolvasás képkockánként',
+    'V4LMultiBuffer'       => 'Multipufferelés',
     'Value'                => 'Érték',
     'Version'              => 'Verzió',
     'VersionIgnore'        => 'Ezen verzió figyelmen kívül hagyása',
@@ -807,7 +808,7 @@ $SLANG = array(
     'VideoGenParms'        => 'Videó készítési paraméterek',
     'VideoGenSucceeded'    => 'A videó elkészült.',
     'VideoSize'            => 'Képméret',
-    'VideoWriter'          => 'Video Writer',           // Added - 2018-08-30
+    'VideoWriter'          => 'Videókiíró',
     'View'                 => 'Megtekintés',
     'ViewAll'              => 'Az összes listázása',
     'ViewEvent'            => 'Események nézet',
@@ -817,7 +818,7 @@ $SLANG = array(
     'Watch'                => 'Figyelés',
     'Web'                  => 'Web',
     'WebColour'            => 'Szín az idővonal skálán',
-    'WebSiteUrl'           => 'Website URL',            // Added - 2018-08-30
+    'WebSiteUrl'           => 'Weboldal URL',
     'Week'                 => 'Héten',
     'White'                => 'Fehér',
     'WhiteBalance'         => 'Fehér egyensúly',
@@ -843,9 +844,9 @@ $SLANG = array(
     'ZoneMinderLog'        => 'ZoneMinder Napló',
     'ZoneOverloadFrames'   => 'Túlterhelés esetén<br>ennyi képkocka hagyható ki',
     'Zones'                => 'Zónák',
-    'Zoom'                 => 'Zoom',
-    'ZoomIn'               => 'Zoom be',
-    'ZoomOut'              => 'Zoom ki',
+    'Zoom'                 => 'Nagyítás',
+    'ZoomIn'               => 'Ránagyítás',
+    'ZoomOut'              => 'Kicsinyítés',
 );
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
@@ -990,7 +991,7 @@ $OLANG = array(
 	
 //    'LANG_DEFAULT' => array(
 //        'Prompt' => "This is a new prompt for this option",
-//        'Help' => "This is some new help for this option which will be displayed in the popup window when the ? is clicked"
+//        'Help' => "This is some new help for this option which will be displayed in the window when the ? is clicked"
 //    ),
 );
 
