@@ -84,7 +84,7 @@ $SLANG = array(
     'AddNewControl'        => 'Aggiungi nuovo Controllo',
     'AddNewMonitor'        => 'Aggiungi nuovo Monitor',
     'AddNewServer'         => 'Aggiungi nuovo Server',         // Added - 2018-08-30
-    'AddNewStorage'        => 'Aggiungi nuovo Storage',        // Added - 2018-08-30
+    'AddNewStorage'        => 'Aggiungi nuovo Archivio',        // Added - 2018-08-30
     'AddNewUser'           => 'Aggiungi nuovo Utente',
     'AddNewZone'           => 'Aggiungi nuova Zona',
     'Alarm'                => 'Allarme',
@@ -95,7 +95,7 @@ $SLANG = array(
     'AlarmMaximumFPS'      => 'FPS massimi durante l\'allarme',
     'AlarmPx'              => 'Pixel Allarme',
     'AlarmRGBUnset'        => 'Devi settare un colore RGB di allarme',
-    'AlarmRefImageBlendPct'=> 'Alarm Reference Image Blend %ge', // Added - 2015-04-18
+    'AlarmRefImageBlendPct'=> 'Riferimento Allarme - Fusione Immagine %', // Added - 2015-04-18
     'Alert'                => 'Attenzione',
     'All'                  => 'Tutto',
     'AnalysisFPS'          => 'Analisi FPS',           // Added - 2015-07-22
@@ -103,14 +103,14 @@ $SLANG = array(
     'Apply'                => 'Applica',
     'ApplyingStateChange'  => 'Sto applicando le modifiche',
     'ArchArchived'         => 'Archiviato',
-    'ArchUnarchived'       => 'Non archiviato',
+    'ArchUnarchived'       => 'Non Archiviato',
     'Archive'              => 'Archivio',
     'Archived'             => 'Archiviato',
     'Area'                 => 'Area',
     'AreaUnits'            => 'Area (px/%)',
-    'AttrAlarmFrames'      => 'Immagini in Allarme',
+    'AttrAlarmFrames'      => 'Immagini Allarme',
     'AttrArchiveStatus'    => 'Stato Archivio',
-    'AttrAvgScore'         => 'Punteggio medio',
+    'AttrAvgScore'         => 'Punteggio Medio',
     'AttrCause'            => 'Causa',
     'AttrDiskBlocks'       => 'Blocchi disco',
     'AttrDiskPercent'      => 'Percentuale disco',
@@ -123,7 +123,7 @@ $SLANG = array(
     'AttrFilterServer'     => 'Filtro attivo su Server', // Added - 2018-08-30
     'AttrFrames'           => 'Immagini',
     'AttrId'               => 'Id',
-    'AttrMaxScore'         => 'Punteggio massimo',
+    'AttrMaxScore'         => 'Punteggio Massimo',
     'AttrMonitorId'        => 'Id Monitor',
     'AttrMonitorName'      => 'Nome Monitor',
     'AttrMonitorServer'    => 'Monitor attivo su Server', // Added - 2018-08-30
@@ -133,11 +133,11 @@ $SLANG = array(
     'AttrStartDateTime'    => 'Inizio - Data/orario',        // Added - 2018-08-30
     'AttrStartTime'        => 'Inizio - Orario',             // Added - 2018-08-30
     'AttrStartWeekday'     => 'Inizio - Giorno della settimana',          // Added - 2018-08-30
-    'AttrStateId'          => 'Stato esecuzione',              // Added - 2018-08-30
-    'AttrStorageArea'      => 'Area Salvataggio',           // Added - 2018-08-30
-    'AttrStorageServer'    => 'Server Salvataggio remoto', // Added - 2018-08-30
-    'AttrSystemLoad'       => 'Carico di sistema',
-    'AttrTotalScore'       => 'Punteggio totale',
+    'AttrStateId'          => 'Stato Esecuzione',              // Added - 2018-08-30
+    'AttrStorageArea'      => 'Area Archiviazione',           // Added - 2018-08-30
+    'AttrStorageServer'    => 'Server Archiviazione remota', // Added - 2018-08-30
+    'AttrSystemLoad'       => 'Carico Sistema',
+    'AttrTotalScore'       => 'Punteggio Totale',
     'Auto'                 => 'Auto',
     'AutoStopTimeout'      => 'Auto Stop Timeout',
     'Available'            => 'Disponibile',              // Added - 2009-03-31
@@ -181,49 +181,49 @@ $SLANG = array(
     'BlobPx'               => 'Blob Px',
     'BlobSizes'            => 'Dimensioni Blob',
     'Blobs'                => 'Blobs',
-    'Brightness'           => 'Luminosità;',
+    'Brightness'           => 'Luminosità',
     'Buffer'               => 'Buffer',                 // Added - 2015-04-18
     'Buffers'              => 'Buffers',
-    'CSSDescription'       => 'Change the default css for this computer', // Added - 2015-04-18
-    'CanAutoFocus'         => 'Può Auto Focus',
-    'CanAutoGain'          => 'Può Auto Gains',
-    'CanAutoIris'          => 'Può Auto Iris',
-    'CanAutoWhite'         => 'Può Auto bil bianco',
-    'CanAutoZoom'          => 'Può Auto Zoom',
-    'CanFocus'             => 'Può Fuoco',
-    'CanFocusAbs'          => 'Può Fuoco Assoluto',
-    'CanFocusCon'          => 'Può Fuoco Continuo ',
-    'CanFocusRel'          => 'Può Fuoco Relativo',
-    'CanGain'              => 'Può Gain ',
-    'CanGainAbs'           => 'Può Gain Assoluto',
-    'CanGainCon'           => 'Può Gain Continuo  ',
-    'CanGainRel'           => 'Può Gain Relativo',
-    'CanIris'              => 'Può Iris',
-    'CanIrisAbs'           => 'Può Iris Assoluto',
-    'CanIrisCon'           => 'Può Iris Continuo  ',
-    'CanIrisRel'           => 'Può Iris Relativo',
-    'CanMove'              => 'Può Mov.',
-    'CanMoveAbs'           => 'Può Mov. Assoluto',
-    'CanMoveCon'           => 'Può Mov. Continuo  ',
-    'CanMoveDiag'          => 'Può Mov. Diagonale ',
-    'CanMoveMap'           => 'Può Mov Mappato',
-    'CanMoveRel'           => 'Può Mov. Relativo',
-    'CanPan'               => 'Può Pan' ,
-    'CanReset'             => 'Può Reset',
-	'CanReboot'             => 'Può Riavviare',
-    'CanSetPresets'        => 'Può impostare preset',
-    'CanSleep'             => 'Può andare in sleep',
-    'CanTilt'              => 'Può Tilt',
-    'CanWake'              => 'Può essere riattivato',
+    'CSSDescription'       => 'Modificare il css predefinito per questo computer', // Added - 2015-04-18
+    'CanAutoFocus'         => 'Può impostare Auto Focus',
+    'CanAutoGain'          => 'Può impostare Auto Gains',
+    'CanAutoIris'          => 'Può impostare Auto Iris',
+    'CanAutoWhite'         => 'Può impostare Auto bil bianco',
+    'CanAutoZoom'          => 'Può impostare Auto Zoom',
+    'CanFocus'             => 'Può impostare Fuoco',
+    'CanFocusAbs'          => 'Può impostare Fuoco Assoluto',
+    'CanFocusCon'          => 'Può impostare Fuoco Continuo',
+    'CanFocusRel'          => 'Può impostare Fuoco Relativo',
+    'CanGain'              => 'Può impostare Guadagno',
+    'CanGainAbs'           => 'Può impostare Guadagno Assoluto',
+    'CanGainCon'           => 'Può impostare Guadagno Continuo  ',
+    'CanGainRel'           => 'Può impostare Guadagno Relativo',
+    'CanIris'              => 'Può impostare Iride',
+    'CanIrisAbs'           => 'Può impostare Iride Assoluto',
+    'CanIrisCon'           => 'Può impostare Iride Continuo',
+    'CanIrisRel'           => 'Può impostare Iride Relativo',
+    'CanMove'              => 'Può impostare Movimento',
+    'CanMoveAbs'           => 'Può impostare Movimento Assoluto',
+    'CanMoveCon'           => 'Può impostare Movimento Continuo',
+    'CanMoveDiag'          => 'Può impostare Movimento Diagonale',
+    'CanMoveMap'           => 'Può impostare Movimento Mappato',
+    'CanMoveRel'           => 'Può impostare Movimento Relativo',
+    'CanPan'               => 'Può impostare Panoramica' ,
+    'CanReset'             => 'Può effettuare Reset',
+    'CanReboot'            => 'Può Riavviare',
+    'CanSetPresets'        => 'Può impostare Preset',
+    'CanSleep'             => 'Può sospendere',
+    'CanTilt'              => 'Può inclinare',
+    'CanWake'              => 'Può riattivare',
     'CanWhite'             => 'Può bilanciare il bianco',
     'CanWhiteAbs'          => 'Può bilanciare il bianco assoluto',
     'CanWhiteBal'          => 'Può bilanciare il bianco',
     'CanWhiteCon'          => 'Può bilanciare il bianco Continuo',
     'CanWhiteRel'          => 'Può bilanciare il bianco Relativo',
-    'CanZoom'              => 'Può Zoom',
-    'CanZoomAbs'           => 'Può Zoom Assoluto',
-    'CanZoomCon'           => 'Può Zoom Continuo',
-    'CanZoomRel'           => 'Può Zoom Relativo',
+    'CanZoom'              => 'Può impostare Zoom',
+    'CanZoomAbs'           => 'Può impostare Zoom Assoluto',
+    'CanZoomCon'           => 'Può impostare Zoom Continuo',
+    'CanZoomRel'           => 'Può impostare Zoom Relativo',
     'Cancel'               => 'Annulla',
     'CancelForcedAlarm'    => 'Annulla Allarme Forzato',
     'CaptureHeight'        => 'Altezza Cattura Immagine',
@@ -238,8 +238,8 @@ $SLANG = array(
     'ChooseLogFormat'      => 'Scegli un formato di registro',    // Added - 2011-06-17
     'ChooseLogSelection'   => 'Scegli una selezione del registro', // Added - 2011-06-17
     'ChoosePreset'         => 'Scegli Preset',
-    'Clear'                => 'Clear',                  // Added - 2011-06-16
-    'CloneMonitor'         => 'Clone',                  // Added - 2018-08-30
+    'Clear'                => 'Pulisci',                  // Added - 2011-06-16
+    'CloneMonitor'         => 'Clona',                  // Added - 2018-08-30
     'Close'                => 'Chiudi',
     'Colour'               => 'Colori',
     'Command'              => 'Comando',
@@ -257,25 +257,25 @@ $SLANG = array(
     'Contrast'             => 'Contrasto',
     'Control'              => 'Controllo',
     'ControlAddress'       => 'Indirizzo di controllo',
-    'ControlCap'           => 'Capacita\' di controllo',
-    'ControlCaps'          => 'Capacita\' di controllo',
+    'ControlCap'           => 'Capacità di controllo',
+    'ControlCaps'          => 'Capacità di controllo',
     'ControlDevice'        => 'Dispositivo di controllo',
     'ControlType'          => 'Tipo Controllo',
     'Controllable'         => 'Controllabile',
-    'Current'              => 'Current',                // Added - 2015-04-18
+    'Current'              => 'Corrente',                // Added - 2015-04-18
     'Cycle'                => 'Cicla',
     'CycleWatch'           => 'Vista Ciclica',
-    'DateTime'             => 'Date/Time',              // Added - 2011-06-16
+    'DateTime'             => 'Data/Orario',              // Added - 2011-06-16
     'Day'                  => 'Giorno',
     'Debug'                => 'Debug',
-    'DefaultRate'          => 'Default Rate',
+    'DefaultRate'          => 'Rateo predefinito',
     'DefaultScale'         => 'Scala di default',
-    'DefaultView'          => 'Visualizzazione di default',
-    'Deinterlacing'        => 'Deinterlacing',          // Added - 2015-04-18
-    'Delay'                => 'Delay',                  // Added - 2015-04-18
+    'DefaultView'          => 'Visualizzazione predefinita',
+    'Deinterlacing'        => 'Deinterlacciamento',          // Added - 2015-04-18
+    'Delay'                => 'Ritardo',                  // Added - 2015-04-18
     'Delete'               => 'Elimina',
-    'DeleteAndNext'        => 'Elimina &amp; Prossimo',
-    'DeleteAndPrev'        => 'Elimina &amp; Precedente',
+    'DeleteAndNext'        => 'Elimina e Prossimo',
+    'DeleteAndPrev'        => 'Elimina e Precedente',
     'DeleteSavedFilter'    => 'Elimina il filtro salvato',
     'Description'          => 'Descrizione',
     'DetectedCameras'      => 'Telecamere Rilevate',       // Added - 2009-03-31
@@ -298,7 +298,7 @@ $SLANG = array(
     'DonateRemindDay'      => 'Non ancora, ricordamelo ancora tra 1 giorno',
     'DonateRemindHour'     => 'Non ancora, ricordamelo ancora tra 1 ora',
     'DonateRemindMonth'    => 'Non ancora, ricordamelo ancora tra 1 mese',
-    'DonateRemindNever'    => 'No, io non voglio donare, non lo faro\' mai',
+    'DonateRemindNever'    => 'No, io non voglio donare, non lo farò mai',
     'DonateRemindWeek'     => 'Non ancora, ricordamelo ancora tra 1 settimana',
     'DonateYes'            => 'Si,mi piacerebbe donare qualcosa ora',
     'Download'             => 'Scarica',
@@ -363,12 +363,12 @@ $SLANG = array(
     'First'                => 'Primo',
     'FlippedHori'          => 'ribaltato orizzontale',
     'FlippedVert'          => 'ribaltato verticale',
-    'FnMocord'              => 'Mocord',            // Added 2013.08.16.
-    'FnModect'              => 'Modect',            // Added 2013.08.16.
-    'FnMonitor'             => 'Monitor',            // Added 2013.08.16.
-    'FnNodect'              => 'Nodect',            // Added 2013.08.16.
-    'FnNone'                => 'None',            // Added 2013.08.16.
-    'FnRecord'              => 'Record',            // Added 2013.08.16.
+    'FnMocord'              => 'Mocord - Registrazione continua (con evidenziazione eventi)',            // Added 2013.08.16.
+    'FnModect'              => 'Modect - MOtion DEteCTtion (registrazione su rilevamento movimento)',            // Added 2013.08.16.
+    'FnMonitor'             => 'Monitor - Visualizza Live',            // Added 2013.08.16.
+    'FnNodect'              => 'Nodect - No DEteCTtion (registrazione su evento esterno)',            // Added 2013.08.16.
+    'FnNone'                => 'None - Nessuno (Monitor disabilitato)',            // Added 2013.08.16.
+    'FnRecord'              => 'Record - Registrazione continua',            // Added 2013.08.16.
     'Focus'                => 'Focus',
     'ForceAlarm'           => 'Forza Allarme',
     'Format'               => 'Formato',
@@ -379,7 +379,7 @@ $SLANG = array(
     'Frames'               => 'Immagini',
     'Func'                 => 'Funz',
     'Function'             => 'Funzione',
-    'Gain'                 => 'Gain',
+    'Gain'                 => 'Guadagno',
     'General'              => 'Generale',
     'GenerateDownload'     => 'Genera download',      // Added - 2018-08-30
     'GenerateVideo'        => 'Genera video',
@@ -391,7 +391,7 @@ $SLANG = array(
     'HasFocusSpeed'        => 'Ha velocità di focus',
     'HasGainSpeed'         => 'Ha velocità di guadagno',
     'HasHomePreset'        => 'Ha posizioni di present',
-    'HasIrisSpeed'         => 'Ha velocotà di iris',
+    'HasIrisSpeed'         => 'Ha velocità di iris',
     'HasPanSpeed'          => 'Ha velocità di Pan',
     'HasPresets'           => 'Ha preset',
     'HasTiltSpeed'         => 'Ha velocità di Tilt',
@@ -401,6 +401,7 @@ $SLANG = array(
     'HasZoomSpeed'         => 'Ha velocità di zoom',
     'High'                 => 'Alta',
     'HighBW'               => 'Banda Alta',
+    'Hight'                => 'Altezza',
     'Home'                 => 'Home',
     'Hostname'             => 'Nome Host',               // Added - 2018-08-30
     'Hour'                 => 'Ora',
@@ -414,7 +415,7 @@ $SLANG = array(
     'In'                   => 'In',
     'Include'              => 'Includi',
     'Inverted'             => 'Invertito',
-    'Iris'                 => 'Iris',
+    'Iris'                 => 'Iride',
     'KeyString'            => 'Stringa Chiave',
     'Label'                => 'Etichetta',
     'Language'             => 'Linguaggio',
@@ -438,7 +439,7 @@ $SLANG = array(
     'Logout'               => 'Logout',
     'Logs'                 => 'Logs',                   // Added - 2011-06-17
     'Low'                  => 'Bassa',
-    'LowBW'                => 'Banda&nbsp;Bassa',
+    'LowBW'                => 'Banda Bassa',
     'Main'                 => 'Principale',
     'Man'                  => 'Man',
     'Manual'               => 'Manuale',
@@ -452,9 +453,9 @@ $SLANG = array(
     'MaxGainRange'         => 'Massimo range del guadagno',
     'MaxGainSpeed'         => 'Massima velocità del guadagno',
     'MaxGainStep'          => 'Massimo step del guadagno',
-    'MaxIrisRange'         => 'Massima range dell\'Iris',
-    'MaxIrisSpeed'         => 'Massima velocità dell\'Iris',
-    'MaxIrisStep'          => 'Massimo step dell\'Iris',
+    'MaxIrisRange'         => 'Massima range dell\'Iride',
+    'MaxIrisSpeed'         => 'Massima velocità dell\'Iride',
+    'MaxIrisStep'          => 'Massimo step dell\'Iride',
     'MaxPanRange'          => 'Massimo range del pan',
     'MaxPanSpeed'          => 'Massima velocità del tilt',
     'MaxPanStep'           => 'Massimo step del pan',
@@ -470,7 +471,7 @@ $SLANG = array(
     'MaximumFPS'           => 'Massimi FPS',
     'Medium'               => 'Media',
     'MediumBW'             => 'Larghezza Banda Media',
-    'Message'              => 'Message',                // Added - 2011-06-16
+    'Message'              => 'Messaggio',                // Added - 2011-06-16
     'MinAlarmAreaLtMax'    => 'L\'area minima dell\'allarme deve essere minore di quella massima',
     'MinAlarmAreaUnset'    => 'Devi specificare il numero minimo di pixel per l\'allarme',
     'MinBlobAreaLtMax'     => 'L\'area di blob minima deve essere minore dell\'area di blob massima',
@@ -487,10 +488,10 @@ $SLANG = array(
     'MinGainRange'         => 'Minimo range del Guadagno',
     'MinGainSpeed'         => 'Velocità minima del Guadagno',
     'MinGainStep'          => 'Step minimo del guadagno',
-    'MinIrisRange'         => 'Range minimo dell\'Iris',
-    'MinIrisSpeed'         => 'Velocità minima dell\'Iris',
-    'MinIrisStep'          => 'Step minimo dell\'Iris',
-    'MinPanRange'          => 'Range minimo del pan',
+    'MinIrisRange'         => 'Range minimo dell\'Iride',
+    'MinIrisSpeed'         => 'Velocità minima dell\'Iride',
+    'MinIrisStep'          => 'Step minimo dell\'Iride',
+    'MinPanRange'          => 'Range minimo del Pan',
     'MinPanSpeed'          => 'Velocità minima del Pan',
     'MinPanStep'           => 'Step minimo del Pan',
     'MinPixelThresLtMax'   => 'I pixel minimi della soglia devono essere minori dei pixel massimi della soglia',
@@ -508,10 +509,10 @@ $SLANG = array(
     'Mode'                 => 'Modalità',                   // Added - 2015-04-18
     'Monitor'              => 'Monitor',
     'MonitorIds'           => 'Monitor Ids',
-    'MonitorPreset'        => 'Monitor Presenti',
-    'MonitorPresetIntro'   => 'Selezionare un appropriato pre settaggio dalla lista riportata qui sotto.<br><br>Per favore notare che questo potrebbe sovrascrivere ogni valore che hai gi&agrave;  configurato su questo monitor.<br><br>',
+    'MonitorPreset'        => 'Monitor Preset',
+    'MonitorPresetIntro'   => 'Selezionare un preset appropriato dalla lista riportata qui sotto.<br><br>Notare che questo potrebbe sovrascrivere ogni valore che hai già configurato su questo monitor.<br><br>',
     'MonitorProbe'         => 'Prova Monitor',          // Added - 2009-03-31
-    'MonitorProbeIntro'    => 'The list below shows detected analog and network cameras and whether they are already being used or available for selection.<br/><br/>Select the desired entry from the list below.<br/><br/>Please note that not all cameras may be detected and that choosing a camera here may overwrite any values you already have configured for the current monitor.<br/><br/>', // Added - 2009-03-31
+    'MonitorProbeIntro'    => 'L\'elenco seguente mostra le telecamere analogiche e di rete rilevate e se sono già in uso o disponibili per la selezione.<br/><br/>Selezionare la voce desiderata dall\'elenco seguente.<br/><br/>Si noti che non tutte le telecamere possono essere rilevate e che la scelta di una telecamera qui potrebbe sovrascrivere tutti i valori già configurati per il monitor corrente.<br/><br/>', // Added - 2009-03-31
     'Monitors'             => 'Monitors',
     'Montage'              => 'Montaggio',
     'MontageReview'        => 'Revisione del montaggio',         // Added - 2018-08-30
@@ -550,7 +551,7 @@ $SLANG = array(
     'NoneAvailable'        => 'Nessuno disponibile',
     'Normal'               => 'Normale',
     'Notes'                => 'Note',
-    'NumPresets'           => 'Num Presets',
+    'NumPresets'           => 'Num redefiniti',
     'Off'                  => 'Off',
     'On'                   => 'On',
     'OnvifCredentialsIntro'=> 'Fornire nome utente e password per la telecamera selezionata.<br/>Se non è stato creato alcun utente per la videocamera, l\'utente qui indicato verrà creato con la password specificata.<br/><br/>', // Added - 2015-04-18
@@ -589,7 +590,7 @@ $SLANG = array(
     'Paths'                => 'Percorsi',
     'Pause'                => 'Pause',
     'Phone'                => 'Telefono',
-    'PhoneBW'              => 'Banda&nbsp;Tel',
+    'PhoneBW'              => 'Banda Tel',
     'Pid'                  => 'PID',                    // Added - 2011-06-16
     'PixelDiff'            => 'Pixel Diff',
     'Pixels'               => 'pixels',
@@ -598,11 +599,11 @@ $SLANG = array(
     'PleaseWait'           => 'Attendere prego',
     'Plugins'              => 'Plugins',
     'Point'                => 'Punto',
-    'PostEventImageBuffer' => 'Buffer di immagini Dopo Evento',
-    'PreEventImageBuffer'  => 'Buffer di immagini Pre Evento',
+    'PostEventImageBuffer' => 'Buffer immagini Dopo Evento',
+    'PreEventImageBuffer'  => 'Buffer immagini Pre Evento',
     'PreserveAspect'       => 'Preserve Aspect Ratio',
     'Preset'               => 'Preset',
-    'Presets'              => 'Presets',
+    'Presets'              => 'Predefiniti',
     'Prev'                 => 'Prec',
     'Probe'                => 'Prova la telecamera',                  // Added - 2009-03-31
     'ProfileProbe'         => 'Prova lo stream',           // Added - 2015-04-18
@@ -631,9 +632,9 @@ $SLANG = array(
     'ReplayAll'            => 'Tutti gli Eventi',
     'ReplayGapless'        => 'Eventi continui',
     'ReplaySingle'         => 'Evento singolo',
-    'ReportEventAudit'     => 'Rapporto Eventi di controllo',    // Added - 2018-08-30
-    'Reset'                => 'Resetta',
-    'ResetEventCounts'     => 'Resetta Contatore Eventi',
+    'ReportEventAudit'     => 'Controllo Eventi',    // Added - 2018-08-30
+    'Reset'                => 'Reset',
+    'ResetEventCounts'     => 'Reset Contatore Eventi',
     'Restart'              => 'Riavvia',
     'Restarting'           => 'Sto riavviando',
     'RestrictedCameraIds'  => 'Camera Ids Riservati',
@@ -661,24 +662,25 @@ $SLANG = array(
     'SelectMonitors'       => 'Monitor Selezionati',
     'SelfIntersecting'     => 'I vertici del poligono non devono intersecarsi',
     'Set'                  => 'Imposta',
-    'SetNewBandwidth'      => 'Imposta nuova Banda',
-    'SetPreset'            => 'Imposta Preset',
+    'SetNewBandwidth'      => 'Imposta Nuova Banda',
+    'SetPreset'            => 'Imposta Predefiniti',
     'Settings'             => 'Impostazioni',
-    'ShowFilterWindow'     => 'MostraFinestraFiltri',
+    'ShowFilterWindow'     => 'Mostra Finestra Filtri',
     'ShowTimeline'         => 'Mostra linea temporale',
+	'Show Zones'           => 'Visualizza Zone',
     'SignalCheckColour'    => 'Colore controllo segnale',
     'SignalCheckPoints'    => 'Punti di controllo segnale',    // Added - 2018-08-30
     'Size'                 => 'grandezza',
     'SkinDescription'      => 'Cambia la skin predefinita per questo computer', // Added - 2011-01-30
-    'Sleep'                => 'Sleep',
-    'SortAsc'              => 'Cresc',
+    'Sleep'                => 'Sospendi',
+    'SortAsc'              => 'Crescente',
     'SortBy'               => 'Ordina per',
-    'SortDesc'             => 'Decr',
+    'SortDesc'             => 'Decrescente',
     'Source'               => 'Sorgente',
     'SourceColours'        => 'Colori della Sorgente',         // Added - 2009-02-08
     'SourcePath'           => 'Percorso della Sorgente',            // Added - 2009-02-08
     'SourceType'           => 'Tipo Sorgente',
-    'Speed'                => 'Velocita\'',
+    'Speed'                => 'Velocità',
     'SpeedHigh'            => 'Alta Velocità',
     'SpeedLow'             => 'Bassa Velocità',
     'SpeedMedium'          => 'Media Velocità',
@@ -698,30 +700,30 @@ $SLANG = array(
     'StepMedium'           => 'Passo medio',
     'StepNone'             => 'Nessun passo',
     'StepSmall'            => 'Passo piccolo',
-    'Stills'               => 'Foto',
+    'Stills'               => 'Immagini fisse',
     'Stop'                 => 'Stop',
     'Stopped'              => 'Inattivo',
-    'StorageArea'          => 'Area di salvataggio',           // Added - 2018-08-30
-    'StorageScheme'        => 'Scheme',                 // Added - 2018-08-30
-    'Stream'               => 'Flusso',
-    'StreamReplayBuffer'   => 'Stream Replay Image Buffer',
+    'StorageArea'          => 'Area Archiviazione',           // Added - 2018-08-30
+    'StorageScheme'        => 'Schema Archiviazione',                 // Added - 2018-08-30
+    'Stream'               => 'Stream',
+    'StreamReplayBuffer'   => 'Buffer immagini riproduzione stream',
     'Submit'               => 'Accetta',
     'System'               => 'Sistema',
     'SystemLog'            => 'Log di sistema',             // Added - 2011-06-16
-    'TargetColorspace'     => 'Target colorspace',      // Added - 2015-04-18
+    'TargetColorspace'     => 'Spazio dei colori obiettivo',      // Added - 2015-04-18
     'Tele'                 => 'Tele',
     'Thumbnail'            => 'Anteprima',
-    'Tilt'                 => 'Tilt',
+    'Tilt'                 => 'Tilt (Inclinazione)',
     'Time'                 => 'Ora',
-    'TimeDelta'            => 'Tempo di Delta',
-    'TimeStamp'            => 'Time Stamp',
+    'TimeDelta'            => 'Differenza orario',
+    'TimeStamp'            => 'Sovraimpressione data/orario',
     'Timeline'             => 'Linea Temporale',
     'TimelineTip1'          => 'Passa il mouse sul grafico per visualizzare un\'immagine dell\'istantanea e i dettagli dell\'evento.',              // Added 2013.08.15.
     'TimelineTip2'          => 'Fai clic sulle sezioni colorate del grafico o sull\'immagine per visualizzare l\'evento.',              // Added 2013.08.15.
     'TimelineTip3'          => 'Fare clic sullo sfondo per ingrandire un periodo di tempo più piccolo basato sul clic.',              // Added 2013.08.15.
     'TimelineTip4'          => 'Utilizzare i controlli seguenti per ridurre o spostarsi avanti e indietro nell\'intervallo di tempo.',              // Added 2013.08.15.
-    'Timestamp'            => 'Timestamp',
-    'TimestampLabelFormat' => 'Formato etichetta timestamp',
+    'Timestamp'            => 'Sovraimpressione data/orario',
+    'TimestampLabelFormat' => 'Formato etichetta Sovraimpressione data/orario',
     'TimestampLabelSize'   => 'Dimensione carattere',              // Added - 2018-08-30
     'TimestampLabelX'      => 'coordinata X etichetta',
     'TimestampLabelY'      => 'coordinata Y etichetta',
@@ -729,9 +731,9 @@ $SLANG = array(
     'Tools'                => 'Strumenti',
     'Total'                => 'Totale',                  // Added - 2011-06-16
     'TotalBrScore'         => 'Punteggio Totale',
-    'TrackDelay'           => 'Track Delay',
-    'TrackMotion'          => 'Track Motion',
-    'Triggers'             => 'Triggers',
+    'TrackDelay'           => 'Ritardo traccia',
+    'TrackMotion'          => 'Segui movimento',
+    'Triggers'             => 'Inneschi/Interruttori',
     'TurboPanSpeed'        => 'Velocità Turbo Pan',
     'TurboTiltSpeed'       => 'Velocità Turbo Tilt',
     'Type'                 => 'Tipo',
@@ -742,17 +744,17 @@ $SLANG = array(
     'Update'               => 'Aggiorna',
     'UpdateAvailable'      => 'Un aggiornamento di ZoneMinder è disponibilie.',
     'UpdateNotNecessary'   => 'Nessun aggiornamento necessario.',
-    'Updated'              => 'Updated',                // Added - 2011-06-16
-    'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'Updated'              => 'Aggiornato',                // Added - 2011-06-16
+    'Upload'               => 'Carica',                 // Added - 2011-08-23
     'UseFilter'            => 'Usa Filtro',
     'UseFilterExprsPost'   => ' espressioni filtri', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Usa&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
-    'UsedPlugins'	   => 'Used Plugins',
+    'UsedPlugins'		   => 'Plugins in uso',
     'User'                 => 'Utente',
     'Username'             => 'Nome Utente',
     'Users'                => 'Utenti',
     'V4L'                  => 'V4L',                    // Added - 2015-04-18
-    'V4LCapturesPerFrame'  => 'Captures Per Frame',     // Added - 2015-04-18
+    'V4LCapturesPerFrame'  => 'Rilevamenti per immagine',     // Added - 2015-04-18
     'V4LMultiBuffer'       => 'Multi Buffering',        // Added - 2015-04-18
     'Value'                => 'Valore',
     'Version'              => 'Versione',
@@ -769,7 +771,7 @@ $SLANG = array(
     'VideoGenParms'        => 'Parametri Generazione Video',
     'VideoGenSucceeded'    => 'Successo: Video Generato!',
     'VideoSize'            => 'Dimensioni Video',
-    'VideoWriter'          => 'Scrittore video',           // Added - 2018-08-30
+    'VideoWriter'          => 'Scrittore Video',           // Added - 2018-08-30
     'View'                 => 'Vedi',
     'ViewAll'              => 'Vedi Tutto',
     'ViewEvent'            => 'Vedi Evento',
@@ -784,12 +786,13 @@ $SLANG = array(
     'White'                => 'Bianco',
     'WhiteBalance'         => 'Bilanciamento del Bianco',
     'Wide'                 => 'Larghezza',
+    'Width'                => 'Larghezza',
     'X'                    => 'X',
     'X10'                  => 'X10',
     'X10ActivationString'  => 'Stringa attivazione X10',
     'X10InputAlarmString'  => 'Stringa allarme input X10',
     'X10OutputAlarmString' => 'Stringa allarme output X10',
-    'Y'                    => 'Y',
+    'Y'                    => 'S',
     'Yes'                  => 'Si',
     'YouNoPerms'           => 'Non hai i permessi per accedere a questa risorsa.',
     'Zone'                 => 'Zona',
@@ -937,17 +940,17 @@ function zmVlang( $langVarArray, $count )
 // So for example, to override the help text for ZM_LANG_DEFAULT do
 $OLANG = array(
 	'OPTIONS_FFMPEG' => array(
-		'Help' => "Parameters in this field are passed on to FFmpeg. Multiple parameters can be separated by ,~~ ".
-		          "Examples (do not enter quotes)~~~~".
-		          "\"allowed_media_types=video\" Set datatype to request fromcam (audio, video, data)~~~~".
-		          "\"reorder_queue_size=nnn\" Set number of packets to buffer for handling of reordered packets~~~~".
-		          "\"loglevel=debug\" Set verbosity of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
+		'Help' => "I parametri in questo campo vengono passati a FFmpeg. Più parametri possono essere separati da ,~~ ".
+		          "Esempi (non inserire virgolette)~~~~".
+		          "\"allowed_media_types=video\" Imposta il tipo di dati da richiedere dalla telecamera (audio, video, data)~~~~".
+		          "\"reorder_queue_size=nnn\" Imposta il numero di pacchetti nel buffer per la gestione dei pacchetti riordinati~~~~".
+		          "\"loglevel=debug\" Imposta la verbosità di FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
 	),
 	'OPTIONS_LIBVLC' => array(
-		'Help' => "Parameters in this field are passed on to libVLC. Multiple parameters can be separated by ,~~ ".
-		          "Examples (do not enter quotes)~~~~".
-		          "\"--rtp-client-port=nnn\" Set local port to use for rtp data~~~~". 
-		          "\"--verbose=2\" Set verbosity of libVLC"
+		'Help' => "I parametri in questo campo vengono passati a libVLC. Più parametri possono essere separati da ,~~ ".
+		          "Esempi (non inserire virgolette)~~~~".
+		          "\"--rtp-client-port=nnn\" Imposta la porta locale da utilizzare per i dati RTP~~~~". 
+		          "\"--verbose=2\" Imposta la verbosità di of libVLC"
 	),
 
 	
