@@ -1,3 +1,12 @@
+<?php
+  global $chart;
+  global $max_aspect_ratio;
+  global $monitors;
+  global $mode;
+  global $monEventSlots;
+?>
+
+
 .chartSize {
     height: <?php echo $chart['height'] ?>px;
 }
@@ -19,6 +28,7 @@
 .imageHeight {
 <?php
 switch ( $max_aspect_ratio ) {
+  case null:
   case 1:
     echo 'padding-top: 100%;'; break;
   case 1.33: // 4:3
