@@ -18,11 +18,8 @@
 // Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 //
 
-$servers = ZM\Server::find(null, array('order'=>'lower(Name)'));
-$ServersById = array();
-foreach ( $servers as $S ) {
-  $ServersById[$S->Id()] = $S;
-}
+require_once('includes/Monitor.php');
+
 zm_session_start();
 foreach ( array('GroupId','Function','ServerId','StorageId','Status','MonitorId','MonitorName','Source') as $var ) {
   if ( isset($_REQUEST[$var]) ) {
@@ -42,29 +39,36 @@ $StorageById = array();
 foreach ( $storage_areas as $S ) {
   $StorageById[$S->Id()] = $S;
 }
+$servers = ZM\Server::find(null, array('order'=>'lower(Name)'));
+$ServersById = array();
+foreach ( $servers as $S ) {
+  $ServersById[$S->Id()] = $S;
+}
 
 $html =
 '
 <div class="controlHeader">
+
   <!-- Used to submit the form with the enter key -->
-  <input type="submit" class="hide"/>
+  <input type="submit" class="d-none"/>
   <input type="hidden" name="filtering" value=""/>
 ';
-
-$GroupsById = array();
-foreach ( ZM\Group::find() as $G ) {
-  $GroupsById[$G->Id()] = $G;
-}
-
 $groupSql = '';
-if ( count($GroupsById) ) {
-  $html .= '<span id="groupControl"><label>'. translate('Group') .'</label>';
-  # This will end up with the group_id of the deepest selection
-  $group_id = isset($_SESSION['GroupId']) ? $_SESSION['GroupId'] : null;
-  $html .= ZM\Group::get_group_dropdown();
-  $groupSql = ZM\Group::get_group_sql($group_id);
-  $html .= '</span>
-';
+if ( canView('Groups') ) {
+  $GroupsById = array();
+  foreach ( ZM\Group::find() as $G ) {
+    $GroupsById[$G->Id()] = $G;
+  }
+
+  if ( count($GroupsById) ) {
+    $html .= '<span id="groupControl"><label>'. translate('Group') .'</label>';
+    # This will end up with the group_id of the deepest selection
+    $group_id = isset($_SESSION['GroupId']) ? $_SESSION['GroupId'] : null;
+    $html .= ZM\Group::get_group_dropdown();
+    $groupSql = ZM\Group::get_group_sql($group_id);
+    $html .= '</span>
+  ';
+  }
 }
 
 $selected_monitor_ids = isset($_SESSION['MonitorId']) ? $_SESSION['MonitorId'] : array();
@@ -100,10 +104,7 @@ $html .= '<input type="text" name="MonitorName" value="'.(isset($_SESSION['Monit
 $html .= '</span>
 ';
 
-$Functions = array();
-foreach ( getEnumValues('Monitors', 'Function') as $optFunction ) {
-  $Functions[$optFunction] = translate('Fn'.$optFunction);
-}
+$Functions = ZM\GetMonitorFunctionTypes();
 
 $html .= '<span class="FunctionFilter"><label>'.translate('Function').'</label>';
 $html .= htmlSelect('Function[]', $Functions,
@@ -170,10 +171,14 @@ $html .= '</span>
   $html .= '</span>
 ';
 
-  $sql = 'SELECT *,S.Status AS Status, S.CaptureFPS AS CaptureFPS, S.AnalysisFPS AS AnalysisFPS, S.CaptureBandwidth AS CaptureBandwidth
-  FROM Monitors AS M LEFT JOIN Monitor_Status AS S ON MonitorId=Id ' .
+  $sql = 'SELECT M.*, S.*, E.*
+  FROM Monitors AS M
+ LEFT JOIN Monitor_Status AS S ON S.MonitorId=M.Id 
+ LEFT JOIN Event_Summaries AS E ON E.MonitorId=M.Id 
+' .
   ( count($conditions) ? ' WHERE ' . implode(' AND ', $conditions) : '' ).' ORDER BY Sequence ASC';
   $monitors = dbFetchAll($sql, null, $values);
+  ZM\Debug(print_r($monitors, true));
   $displayMonitors = array();
   $monitors_dropdown = array();
 
