@@ -1,4 +1,12 @@
+var ZM_OPT_USE_GEOLOCATION = '<?php echo ZM_OPT_USE_GEOLOCATION ?>' == '1' ? true : false;
+<?php
+if ( ZM_OPT_USE_GEOLOCATION ) { 
+  echo 'var ZM_OPT_GEOLOCATION_TILE_PROVIDER=\''.ZM_OPT_GEOLOCATION_TILE_PROVIDER.'\''.PHP_EOL;
+  echo 'var ZM_OPT_GEOLOCATION_ACCESS_TOKEN=\''.ZM_OPT_GEOLOCATION_ACCESS_TOKEN.'\''.PHP_EOL;
+}
+?>
 var optControl = <?php echo ZM_OPT_CONTROL ?>;
+var hasOnvif = <?php echo ZM_HAS_ONVIF ?>;
 var defaultAspectRatio = '<?php echo ZM_DEFAULT_ASPECT_RATIO ?>';
 
 <?php
@@ -6,33 +14,30 @@ if ( ZM_OPT_CONTROL ) {
 ?>
 var controlOptions = new Object();
 <?php
-  global $controlTypes;
-  $controlTypes = array( ''=>translate('None') );
-  # Temporary workaround to show all ptz control types regardless of monitor source type
-  #    $sql = "select * from Controls where Type = '".$newMonitor['Type']."'";
-  $sql = 'SELECT `Id`,`Name`,`HasHomePreset`,`NumPresets` FROM `Controls` ORDER BY lower(`Name`)';
-  foreach( dbFetchAll($sql) as $row ) {
-    $controlTypes[$row['Id']] = $row['Name'];
+  global $controls;
+  foreach ( $controls as $control ) {
     echo '
-controlOptions['.$row['Id'].'] = new Array();
-controlOptions['.$row['Id'].'][0] = '.
-    ( $row['HasHomePreset'] ? '\''.translate('Home').'\'' : 'null' ).'
-';
-    for ( $i = 1; $i <= $row['NumPresets']; $i++ ) {
-      echo 'controlOptions['. $row['Id'].']['.$i.'] = \''.translate('Preset').' '.$i .'\';
-';
+controlOptions['.$control->Id().'] = new Array();
+controlOptions['.$control->Id().'][0] = '.
+    ( $control->HasHomePreset() ? '\''.translate('Home').'\'' : 'null' ).PHP_EOL;
+    for ( $i = 1; $i <= $control->NumPresets(); $i++ ) {
+      echo 'controlOptions['. $control->Id().']['.$i.'] = \''.translate('Preset').' '.$i .'\';'.PHP_EOL;
     }
   } # end foreach row
 } # end if ZM_OPT_CONTROL
 ?>
 
 var monitorNames = new Object();
+var rtspStreamNames = new Object();
 <?php
-$query = empty($_REQUEST['mid']) ? dbQuery('SELECT Name FROM Monitors') : dbQuery('SELECT Name FROM Monitors WHERE Id != ?', array($_REQUEST['mid']) );
-if ( $query ) {
-  while ( $name = dbFetchNext($query, 'Name') ) {
+$query = empty($_REQUEST['mid']) ?
+  dbQuery('SELECT Name,RTSPStreamName FROM Monitors') :
+  dbQuery('SELECT Name,RTSPStreamName FROM Monitors WHERE Id != ?', array($_REQUEST['mid']) );
+if ($query) {
+  while ($row = dbFetchNext($query)) {
     echo '
-monitorNames[\''.validJsStr($name).'\'] = true;
+monitorNames[\''.validJsStr($row['Name']).'\'] = true;
+rtspStreamNames[\''.validJsStr($row['RTSPStreamName']).'\'] = true;
 ';
   } // end foreach
 } # end if query
@@ -40,6 +45,7 @@ monitorNames[\''.validJsStr($name).'\'] = true;
 
 function validateForm( form ) {
   var errors = new Array();
+  var warnings = new Array();
 
   if ( form.elements['newMonitor[Name]'].value.search( /[^\w\-\.\(\)\:\/ ]/ ) >= 0 )
     errors[errors.length] = "<?php echo translate('BadNameChars') ?>";
@@ -55,6 +61,8 @@ function validateForm( form ) {
       errors[errors.length] = "<?php echo translate('BadChannel') ?>";
     if ( !form.elements['newMonitor[Format]'].value || !form.elements['newMonitor[Format]'].value.match( /^\d+$/ ) )
       errors[errors.length] = "<?php echo translate('BadFormat') ?>";
+    if ( form.elements['newMonitor[VideoWriter]'].value == 2 /* Passthrough */ )
+      errors[errors.length] = "<?php echo translate('BadPassthrough') ?>";
   } else if ( form.elements['newMonitor[Type]'].value == 'Remote' ) {
     //if ( !form.elements['newMonitor[Host]'].value || !form.elements['newMonitor[Host]'].value.match( /^[0-9a-zA-Z_.:@-]+$/ ) )
       //errors[errors.length] = "<?php echo translate('BadHost') ?>";
@@ -62,14 +70,20 @@ function validateForm( form ) {
       errors[errors.length] = "<?php echo translate('BadPort') ?>";
     //if ( !form.elements['newMonitor[Path]'].value )
       //errors[errors.length] = "<?php echo translate('BadPath') ?>";
+    if ( form.elements['newMonitor[VideoWriter]'].value == 2 /* Passthrough */ )
+      errors[errors.length] = "<?php echo translate('BadPassthrough') ?>";
   } else if ( form.elements['newMonitor[Type]'].value == 'Ffmpeg' ) {
-    if ( !form.elements['newMonitor[Path]'].value )
-//|| !form.elements['newMonitor[Path]'].value.match( /^\d+$/ ) ) // valid url
+    if ( !form.elements['newMonitor[Path]'].value ) {
       errors[errors.length] = "<?php echo translate('BadPath') ?>";
+    } else if (form.elements['newMonitor[Path]'].value.match(/[\!\*'\(\)\$ ,#]/)) {
+      warnings[warnings.length] = "<?php echo translate('BadPathNotEncoded') ?>";
+    }
 
   } else if ( form.elements['newMonitor[Type]'].value == 'File' ) {
     if ( !form.elements['newMonitor[Path]'].value )
       errors[errors.length] = "<?php echo translate('BadPath') ?>";
+    if ( form.elements['newMonitor[VideoWriter]'].value == 2 /* Passthrough */ )
+      errors[errors.length] = "<?php echo translate('BadPassthrough') ?>";
   } else if ( form.elements['newMonitor[Type]'].value == 'WebSite' ) {
     if ( form.elements['newMonitor[Function]'].value != 'Monitor' && form.elements['newMonitor[Function]'].value != 'None')
       errors[errors.length] = "<?php echo translate('BadSourceType') ?>";
@@ -77,6 +91,13 @@ function validateForm( form ) {
       errors[errors.length] = "<?php echo translate('BadWebSitePath') ?>";
   }
 
+  if (form.elements['newMonitor[VideoWriter]'].value == '1' /* Encode */) {
+    var parameters = form.elements['newMonitor[EncoderParameters]'].value.replace(/[^#a-zA-Z]/g, "");
+    if (parameters == '' || parameters == '#Linesbeginningwith#areacomment#Forchangingqualityusethecrfoption#isbestisworstquality#crf' ) {
+      warnings[warnings.length] = '<?php echo translate('BadEncoderParameters') ?>';
+    }
+  }
+
   if ( form.elements['newMonitor[Type]'].value != 'WebSite' ) {
 
     if ( form.elements['newMonitor[AnalysisFPSLimit]'].value && !(parseFloat(form.elements['newMonitor[AnalysisFPSLimit]'].value) > 0 ) )
@@ -98,11 +119,15 @@ function validateForm( form ) {
       errors[errors.length] = "<?php echo translate('BadLabelX') ?>";
     if ( !form.elements['newMonitor[LabelY]'].value || !(parseInt(form.elements['newMonitor[LabelY]'].value) >= 0 ) )
       errors[errors.length] = "<?php echo translate('BadLabelY') ?>";
-    if ( !form.elements['newMonitor[ImageBufferCount]'].value || !(parseInt(form.elements['newMonitor[ImageBufferCount]'].value) >= 10 ) )
+    if ( !form.elements['newMonitor[ImageBufferCount]'].value || !(parseInt(form.elements['newMonitor[ImageBufferCount]'].value) >= 2 ) )
       errors[errors.length] = "<?php echo translate('BadImageBufferCount') ?>";
     if ( !form.elements['newMonitor[WarmupCount]'].value || !(parseInt(form.elements['newMonitor[WarmupCount]'].value) >= 0 ) )
       errors[errors.length] = "<?php echo translate('BadWarmupCount') ?>";
-    if ( !form.elements['newMonitor[PreEventCount]'].value || !(parseInt(form.elements['newMonitor[PreEventCount]'].value) >= 0 ) || (parseInt(form.elements['newMonitor[PreEventCount]'].value) > parseInt(form.elements['newMonitor[ImageBufferCount]'].value)) )
+    if ( 
+      !form.elements['newMonitor[PreEventCount]'].value
+      ||
+      !(parseInt(form.elements['newMonitor[PreEventCount]'].value) >= 0)
+      )
       errors[errors.length] = "<?php echo translate('BadPreEventCount') ?>";
     if ( !form.elements['newMonitor[PostEventCount]'].value || !(parseInt(form.elements['newMonitor[PostEventCount]'].value) >= 0 ) )
       errors[errors.length] = "<?php echo translate('BadPostEventCount') ?>";
@@ -125,15 +150,19 @@ function validateForm( form ) {
         errors[errors.length] = "<?php echo translate('BadSignalCheckColour') ?>";
     if ( !form.elements['newMonitor[WebColour]'].value || !form.elements['newMonitor[WebColour]'].value.match( /^[#0-9a-zA-Z]+$/ ) )
       errors[errors.length] = "<?php echo translate('BadWebColour') ?>";
-
   }
 
+  if ( form.elements['newMonitor[RTSPStreamName]'].value
+      &&
+      rtspStreamNames[form.elements['newMonitor[RTSPStreamName]'].value]
+    )
+    errors[errors.length] = "<?php echo translate('DuplicateRTSPStreamName') ?>";
+
   if ( errors.length ) {
     alert(errors.join("\n"));
     return false;
   }
 
-  var warnings = new Array();
   if ( (form.elements['newMonitor[Function]'].value != 'Monitor') && (form.elements['newMonitor[Function]'].value != 'None') ) {
     if ( (form.elements['newMonitor[SaveJPEGs]'].value == '0') && (form.elements['newMonitor[VideoWriter]'].value == '0') ) {
       warnings[warnings.length] = "<?php echo translate('BadNoSaveJPEGsOrVideoWriter'); ?>";
@@ -157,6 +186,7 @@ function updateMethods(element) {
   switch ( element.value ) {
     case 'http' :
       <?php
+        global $httpMethods;
         foreach( $httpMethods as $value=>$label ) {
           ?>
             methodSelector.options[methodSelector.options.length] = new Option("<?php echo htmlspecialchars($label) ?>", "<?php echo $value ?>");
@@ -168,6 +198,7 @@ function updateMethods(element) {
           break;
     case 'rtsp' :
       <?php
+        global $rtspMethods;
         foreach( $rtspMethods as $value=>$label ) {
           ?>
             methodSelector.options[methodSelector.options.length] = new Option( "<?php echo htmlspecialchars($label) ?>", "<?php echo $value ?>" );
