@@ -57,7 +57,7 @@ function getFrame(monId, time, last_Frame) {
 
   var events_for_monitor = events_by_monitor_id[monId];
   if ( !events_for_monitor ) {
-    console.log("No events for monitor " + monId);
+    //console.log("No events for monitor " + monId);
     return;
   }
 
@@ -498,8 +498,8 @@ function redrawScreen() {
     drawGraph();
   }
 
+  var monitors = $j('#monitors');
   if ( fitMode == 1 ) {
-    var monitors = $j('#monitors');
     var fps = $j('#fps');
     var vh = window.innerHeight;
     var mh = (vh - monitors.position().top - fps.outerHeight());
@@ -648,8 +648,11 @@ function setSpeed(speed_index) {
 }
 
 function setLive(value) {
+  // When we submit the context etc goes away but we may still be trying to update
+  // So kill the timer.
+  clearInterval(timerObj);
   liveMode = value;
-  var form = $j('#montagereview_form')[0];
+  var form = document.getElementById('montagereview_form');
   form.elements['live'].value = value;
   form.submit();
   return false;
@@ -985,6 +988,19 @@ function initPage() {
     });
   });
 
+  if ( !liveMode ) {
+    canvas = document.getElementById('timeline');
+
+    canvas.addEventListener('mousemove', mmove, false);
+    canvas.addEventListener('touchmove', tmove, false);
+    canvas.addEventListener('mousedown', mdown, false);
+    canvas.addEventListener('mouseup', mup, false);
+    canvas.addEventListener('mouseout', mout, false);
+
+    ctx = canvas.getContext('2d');
+    drawGraph();
+  }
+
   for ( var i = 0, len = monitorPtr.length; i < len; i += 1 ) {
     var monId = monitorPtr[i];
     if ( !monId ) continue;
@@ -1006,18 +1022,6 @@ function initPage() {
     }
   } // end foreach monitor
 
-  if ( !liveMode ) {
-    canvas = document.getElementById('timeline');
-
-    canvas.addEventListener('mousemove', mmove, false);
-    canvas.addEventListener('touchmove', tmove, false);
-    canvas.addEventListener('mousedown', mdown, false);
-    canvas.addEventListener('mouseup', mup, false);
-    canvas.addEventListener('mouseout', mout, false);
-
-    ctx = canvas.getContext('2d');
-    drawGraph();
-  }
   setSpeed(speedIndex);
   //setFit(fitMode);  // will redraw
   //setLive(liveMode);  // will redraw
