@@ -36,26 +36,24 @@ $focusWindow = true;
 xhtmlHeaders(__FILE__, translate('MonitorPreset') );
 ?>
 <body>
+  <?php echo getNavBarHTML() ?>
   <div id="page">
-    <div id="header">
       <h2><?php echo translate('MonitorPreset') ?></h2>
-    </div>
     <div id="content">
-      <form name="contentForm" id="contentForm" method="post" action="?">
+      <form name="contentForm" id="monitorPresetForm" method="post" action="?">
         <input type="hidden" name="view" value="none"/>
         <input type="hidden" name="mid" value="<?php echo validNum($_REQUEST['mid']) ?>"/>
         <p>
           <?php echo translate('MonitorPresetIntro') ?>
         </p>
         <p>
-          <label for="preset"><?php echo translate('Preset') ?></label><?php echo buildSelect( "preset", $presets, 'configureButtons( this )' ); ?>
+          <label for="preset"><?php echo translate('Preset') ?></label><?php echo buildSelect( "preset", $presets ); ?>
         </p>
         <div id="contentButtons">
           <input type="submit" name="saveBtn" value="<?php echo translate('Save') ?>" data-on-click-this="submitPreset" disabled="disabled"/>
-          <input type="button" value="<?php echo translate('Cancel') ?>" data-on-click="closeWindow"/>
+          <input type="button" value="<?php echo translate('Cancel') ?>" data-on-click="backWindow"/>
         </div>
       </form>
     </div>
   </div>
-</body>
-</html>
+<?php xhtmlFooter() ?>
