@@ -32,7 +32,7 @@
 //     If both scale and either width or height are specified, scale is ignored
 //
 
-if ( !canView('Events') ) {
+if ( !canView('Events') and ($_REQUEST['fid'] != 'snapshot' or !canView('Snapshots'))) {
   $view = 'error';
   return;
 }
@@ -57,6 +57,7 @@ $filename = '';
 $Frame = null;
 $Event = null;
 $path = null;
+$media_type='image/jpeg';
 
 if ( empty($_REQUEST['path']) ) {
 
@@ -77,6 +78,47 @@ if ( empty($_REQUEST['path']) ) {
     }
 
     if ( $_REQUEST['fid'] == 'objdetect' ) {
+        // if animation file is found, return that, else return image
+        // we are only looking for GIF or jpg here, not mp4
+        // as most often, browsers asking for this link will be expecting
+        // media types that can be rendered as <img src=>
+        $path_anim_gif = $Event->Path().'/objdetect.gif';
+        $path_image = $Event->Path().'/objdetect.jpg';
+        if (file_exists($path_anim_gif)) {
+          // we found the animation gif file
+          $media_type = 'image/gif';
+          ZM\Debug("Animation file found at $path");
+          $path = $path_anim_gif;
+        } else if (file_exists($path_image)) {
+            // animation not found, but image found
+            ZM\Debug("Image file found at $path");
+            $path = $path_image;
+        } else {
+            // neither animation nor image found
+            header('HTTP/1.0 404 Not Found');
+            ZM\Fatal("Object detection animation and image not found for this event");  
+        }
+        $Frame = new ZM\Frame();
+        $Frame->Id('objdetect');
+      } else if ( $_REQUEST['fid'] == 'objdetect_mp4' ) {
+        $path = $Event->Path().'/objdetect.mp4';
+        if ( !file_exists($path) ) {
+          header('HTTP/1.0 404 Not Found');
+          ZM\Fatal("File $path does not exist. You might not have enabled create_animation in objectconfig.ini. If you have, inspect debug logs for errors during creation");
+          }
+        $Frame = new ZM\Frame();
+        $Frame->Id('objdetect');
+        $media_type = 'video/mp4';
+      } else if ( $_REQUEST['fid'] == 'objdetect_gif' ) {
+        $path = $Event->Path().'/objdetect.gif';
+        if ( !file_exists($path) ) {
+          header('HTTP/1.0 404 Not Found');
+          ZM\Fatal("File $path does not exist. You might not have enabled create_animation in objectconfig.ini. If you have, inspect debug logs for errors during creation");
+      }
+      $Frame = new ZM\Frame();
+      $Frame->Id('objdetect');
+      $media_type = 'image/gif';
+    } else if ( $_REQUEST['fid'] == 'objdetect_jpg' ) {
       $path = $Event->Path().'/objdetect.jpg';
       if ( !file_exists($path) ) {
         header('HTTP/1.0 404 Not Found');
@@ -136,9 +178,33 @@ if ( empty($_REQUEST['path']) ) {
           # If we store Frames as jpgs, then we don't store a snapshot
           $path = $Event->Path().'/'.sprintf('%0'.ZM_EVENT_IMAGE_DIGITS.'d', $Frame->FrameId()).'-'.$show.'.jpg';
         } else {
-          header('HTTP/1.0 404 Not Found');
-          ZM\Fatal('No alarm jpg found for event '.$_REQUEST['eid']);
-          return;
+          if ( $Event->DefaultVideo() ) {
+            $command = ZM_PATH_FFMPEG.' -ss '. $Frame->Delta() .' -i '.$Event->Path().'/'.$Event->DefaultVideo().' -frames:v 1 '.$path . ' 2>&1';
+            #$command ='ffmpeg -ss '. $Frame->Delta() .' -i '.$Event->Path().'/'.$Event->DefaultVideo().' -vf "select=gte(n\\,'.$Frame->FrameId().'),setpts=PTS-STARTPTS" '.$path;
+            #$command ='ffmpeg -v 0 -i '.$Storage->Path().'/'.$Event->Path().'/'.$Event->DefaultVideo().' -vf "select=gte(n\\,'.$Frame->FrameId().'),setpts=PTS-STARTPTS" '.$path;
+            ZM\Debug("Running $command");
+            $output = array();
+            $retval = 0;
+            exec($command, $output, $retval);
+            ZM\Debug("Command: $command, retval: $retval, output: " . implode("\n", $output));
+            if ( ! file_exists($path) ) {
+              header('HTTP/1.0 404 Not Found');
+              ZM\Fatal('Can\'t create frame images from video for this event '.$Event->DefaultVideo().'
+
+                Command was: '.$command.'
+
+                Output was: '.implode(PHP_EOL,$output) );
+            }
+            # Generating an image file will use up more disk space, so update the Event record.
+            if ( $Event->EndDateTime() ) {
+              $Event->DiskSpace(null);
+              $Event->save();
+            }
+          } else {
+            header('HTTP/1.0 404 Not Found');
+            ZM\Fatal('No snapshot jpg found for event '.$_REQUEST['eid']);
+            return;
+          }
         } # end if stored jpgs
       } else {
         $Frame = new ZM\Frame();
@@ -146,9 +212,8 @@ if ( empty($_REQUEST['path']) ) {
         $Frame->FrameId('snapshot');
       } # end if found snapshot.jpg
     } else {
-
       $Frame = ZM\Frame::find_one(array('EventId'=>$_REQUEST['eid'], 'FrameId'=>$_REQUEST['fid']));
-      if ( ! $Frame ) {
+      if (!$Frame) {
         $previousBulkFrame = dbFetchOne(
           'SELECT * FROM Frames WHERE EventId=? AND FrameId < ? ORDER BY FrameID DESC LIMIT 1',
           NULL, array($_REQUEST['eid'], $_REQUEST['fid'])
@@ -157,22 +222,22 @@ if ( empty($_REQUEST['path']) ) {
           'SELECT * FROM Frames WHERE EventId=? AND FrameId > ? ORDER BY FrameID ASC LIMIT 1',
           NULL, array($_REQUEST['eid'], $_REQUEST['fid'])
         );
-        if ( $previousBulkFrame and $nextBulkFrame ) {
+        if ($previousBulkFrame and $nextBulkFrame) {
           $Frame = new ZM\Frame($previousBulkFrame);
           $Frame->FrameId($_REQUEST['fid']);
 
           $percentage = ($Frame->FrameId() - $previousBulkFrame['FrameId']) / ($nextBulkFrame['FrameId'] - $previousBulkFrame['FrameId']);
 
           $Frame->Delta($previousBulkFrame['Delta'] + floor( 100* ( $nextBulkFrame['Delta'] - $previousBulkFrame['Delta'] ) * $percentage )/100);
-          ZM\Logger::Debug("Got virtual frame from Bulk Frames previous delta: " . $previousBulkFrame['Delta'] . " + nextdelta:" . $nextBulkFrame['Delta'] . ' - ' . $previousBulkFrame['Delta'] . ' * ' . $percentage );
+          ZM\Debug('Got virtual frame from Bulk Frames previous delta: ' . $previousBulkFrame['Delta'] . ' + nextdelta:' . $nextBulkFrame['Delta'] . ' - ' . $previousBulkFrame['Delta'] . ' * ' . $percentage );
         } else {
           ZM\Fatal('No Frame found for event('.$_REQUEST['eid'].') and frame id('.$_REQUEST['fid'].')');
         }
-      }
+      }  # end if !Frame
       // Frame can be non-existent.  We have Bulk frames.  So now we should try to load the bulk frame 
       $path = $Event->Path().'/'.sprintf('%0'.ZM_EVENT_IMAGE_DIGITS.'d',$Frame->FrameId()).'-'.$show.'.jpg';
-      ZM\Logger::Debug("Path: $path");
-    }
+      ZM\Debug("Path: $path");
+    }  # if special frame (snapshot, alarm etc) or identified by id
 
   } else {
 # If we are only specifying fid, then the fid must be the primary key into the frames table. But when the event is specified, then it is the frame #
@@ -193,28 +258,34 @@ if ( empty($_REQUEST['path']) ) {
   } # end if have eid
     
   if ( !file_exists($path) ) {
-    ZM\Logger::Debug("$path does not exist");
+    ZM\Debug("$path does not exist");
     # Generate the frame JPG
     if ( ($show == 'capture') and $Event->DefaultVideo() ) {
       if ( !file_exists($Event->Path().'/'.$Event->DefaultVideo()) ) {
         header('HTTP/1.0 404 Not Found');
         ZM\Fatal("Can't create frame images from video because there is no video file for this event at (".$Event->Path().'/'.$Event->DefaultVideo() );
       }
-      $command = ZM_PATH_FFMPEG.' -ss '. $Frame->Delta() .' -i '.$Event->Path().'/'.$Event->DefaultVideo().' -frames:v 1 '.$path;
+      $command = ZM_PATH_FFMPEG.' -ss '. $Frame->Delta() .' -i '.$Event->Path().'/'.$Event->DefaultVideo().' -frames:v 1 '.$path . ' 2>&1';
       #$command ='ffmpeg -ss '. $Frame->Delta() .' -i '.$Event->Path().'/'.$Event->DefaultVideo().' -vf "select=gte(n\\,'.$Frame->FrameId().'),setpts=PTS-STARTPTS" '.$path;
 #$command ='ffmpeg -v 0 -i '.$Storage->Path().'/'.$Event->Path().'/'.$Event->DefaultVideo().' -vf "select=gte(n\\,'.$Frame->FrameId().'),setpts=PTS-STARTPTS" '.$path;
-      ZM\Logger::Debug("Running $command");
+      ZM\Debug("Running $command");
       $output = array();
       $retval = 0;
-      exec( $command, $output, $retval );
-      ZM\Logger::Debug("Command: $command, retval: $retval, output: " . implode("\n", $output));
-      if ( ! file_exists( $path ) ) {
+      exec($command, $output, $retval);
+      ZM\Debug("Command: $command, retval: $retval, output: " . implode("\n", $output));
+      if ( ! file_exists($path) ) {
         header('HTTP/1.0 404 Not Found');
-        ZM\Fatal('Can\'t create frame images from video for this event '.$Event->DefaultVideo() );
+        ZM\Fatal('Can\'t create frame images from video for this event '.$Event->DefaultVideo().'
+
+Command was: '.$command.'
+
+Output was: '.implode(PHP_EOL,$output) );
       }
       # Generating an image file will use up more disk space, so update the Event record.
-      $Event->DiskSpace(null);
-      $Event->save();
+      if ( $Event->EndDateTime() ) {
+        $Event->DiskSpace(null);
+        $Event->save();
+      }
     } else {
       header('HTTP/1.0 404 Not Found');
       ZM\Fatal("Can't create frame $show images from video because there is no video file for this event at ".
@@ -281,7 +352,7 @@ if ( !empty($_REQUEST['height']) ) {
 if ( $errorText ) {
   ZM\Error($errorText);
 } else {
-  header('Content-type: image/jpeg');
+  header('Content-type: '.$media_type);
   if ( ( $scale==0 || $scale==100 ) && ($width==0) && ($height==0) ) {
     # This is so that Save Image As give a useful filename
     if ( $Event ) {
@@ -292,8 +363,8 @@ if ( $errorText ) {
       ZM\Error('No bytes read from '. $path);
     }
   } else {
-    ZM\Logger::Debug("Doing a scaled image: scale($scale) width($width) height($height)");
-    $i = 0;
+    ZM\Debug("Doing a scaled image: scale($scale) width($width) height($height)");
+    $i = null;
     if ( ! ( $width && $height ) ) {
       $i = imagecreatefromjpeg($path);
       $oldWidth = imagesx($i);
@@ -305,7 +376,7 @@ if ( $errorText ) {
         $width = ($height * $oldWidth) / $oldHeight;
       } elseif ( $width != 0 && $height == 0 ) {
         $height = ($width * $oldHeight) / $oldWidth;
-ZM\Logger::Debug("Figuring out height using width: $height = ($width * $oldHeight) / $oldWidth");
+ZM\Debug("Figuring out height using width: $height = ($width * $oldHeight) / $oldWidth");
       }
       if ( $width == $oldWidth && $height == $oldHeight ) {
         ZM\Warning('No change to width despite scaling.');
@@ -314,29 +385,40 @@ ZM\Logger::Debug("Figuring out height using width: $height = ($width * $oldHeigh
   
     # Slight optimisation, thumbnails always specify width and height, so we can cache them.
     $scaled_path = preg_replace('/\.jpg$/', "-${width}x${height}.jpg", $path);
-    if ( $Event ) {
+    if ($Event) {
       $filename = $Event->MonitorId().'_'.$Event->Id().'_'.$Frame->FrameId()."-${width}x${height}.jpg";
       header('Content-Disposition: inline; filename="' . $filename . '"');
     }
     if ( !( file_exists($scaled_path) and readfile($scaled_path) ) ) {
-      ZM\Logger::Debug("Cached scaled image does not exist at $scaled_path or is no good.. Creating it");
-      ob_start();
-      if ( !$i )
+      ZM\Debug("Cached scaled image does not exist at $scaled_path or is no good.. Creating it");
+      if (!$i)
         $i = imagecreatefromjpeg($path);
-      $iScale = imagescale($i, $width, $height);
-      imagejpeg($iScale);
-      imagedestroy($i);
-      imagedestroy($iScale);
-      $scaled_jpeg_data = ob_get_contents();
-      file_put_contents($scaled_path, $scaled_jpeg_data);
-      echo $scaled_jpeg_data;
+      if ( !$i) {
+        ZM\Error('Unable to load jpeg from '.$scaled_path);
+        $i  = imagecreatetruecolor($width, $height);
+        $bg_colour = imagecolorallocate($i, 255, 255, 255);
+        $fg_colour = imagecolorallocate($i, 0, 0, 0);
+        imagefilledrectangle($im, 0, 0, $width, $height, $bg_colour);
+        imagestring($i, 1, 5, 5, 'Unable to load jpeg from  ' . $scaled_path, $fg_colour);
+        imagejpeg($i);
+      } else {
+        ZM\Debug("Have image scaling to $width x $height");
+        ob_start();
+        $iScale = imagescale($i, $width, $height);
+        imagejpeg($iScale);
+        imagedestroy($i);
+        imagedestroy($iScale);
+        $scaled_jpeg_data = ob_get_contents();
+        file_put_contents($scaled_path, $scaled_jpeg_data);
+        echo $scaled_jpeg_data;
+      }
     } else {
-      ZM\Logger::Debug("Sending $scaled_path");
+      ZM\Debug("Sending $scaled_path");
       $bytes = readfile($scaled_path);
       if ( !$bytes ) {
         ZM\Error('No bytes read from '. $scaled_path);
       } else {
-        ZM\Logger::Debug("$bytes sent");
+        ZM\Debug("$bytes sent");
       }
     }
   }
